<?php

if ( ! defined('ABSPATH') ) exit; // Exit if accessed directly

class FormWidget extends WP_Widget {

    // constructor
    public function __construct() {
        parent::__construct(
            'rodio_form_widget',
            esc_html__( 'RODIO: Form Widget', 'rodio-core'),
            [
                'classname' => 'rodio-form-widget',
                'description' => esc_html__( 'Widget to add a contact form in a sidebar.', 'rodio-core' )
            ]
        );
    }

    // front end of the widget
    public function widget( $args, $instance ) {
        // before content
        echo $args['before_widget'];

        $title = ! empty( $instance['title'] ) ? $instance['title'] : '';
        $form = ! empty( $instance['form'] ) ? $instance['form'] : '';

        if ( $title ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

        ?>
            <div class="contact-form">
                <?php echo do_shortcode('[contact-form-7 id="' . $form . '"]'); ?>
            </div>
        <?php

        // after content
        echo $args['after_widget'];
    }

    // back end of the widget
    public function form( $instance ) {
        // default values
        $instance = wp_parse_args( 
            (array) $instance, 
            [ 
                'title' => '',
                'form' => ''
        ] );
        $contact_forms = $this->get_contact_form();
        ?>
        <!-- title field - start -->
        <p>
			<label 
            for="<?php echo $this->get_field_id( 'title' ); ?>">
                <?php _e( 'Title:' ); ?>
            </label>

			<input 
            class="widefat" 
            id="<?php echo $this->get_field_id( 'title' ); ?>" 
            name="<?php echo $this->get_field_name( 'title' ); ?>" 
            type="text" 
            value="<?php echo esc_attr( $instance['title'] ); ?>"
            />
		</p>
        <!-- title field - end -->

        <!-- form field - start -->
        <p>
            <label 
            for="<?php echo $this->get_field_id( 'form' ); ?>">
                <?php _e( 'Form:' ); ?>
            </label>

            <select
            class="widefat" 
            name="<?php echo $this->get_field_name( 'form' ); ?>"
            id="<?php echo $this->get_field_id( 'form' ); ?>" 
            >
                <?php foreach ( $contact_forms as $key => $form ): ?>
                    <option
                    <?php echo esc_attr( $key == $instance['form'] ? 'selected ' : '' );  ?>
                    value="<?php echo esc_attr( $key ); ?>"
                    >
                        <?php echo esc_html( $form ); ?>
                    </option>
                <?php endforeach; ?>
            </select>

            <br/>
        </p>
        <!-- form field - end -->
        <?php
    }

    // update widget
    public function update( $new_instance, $old_instance ) {
        $instance                 = $old_instance;
		$instance['title']        = sanitize_text_field( $new_instance['title'] );
		$instance['form']         = sanitize_text_field( $new_instance['form'] );

		return $instance;
    }

    // get contact forms
    public function get_contact_form() {
        $args = [
            'post_type' => 'wpcf7_contact_form', 
            'posts_per_page' => -1
        ];

        $catlist = [];
    
        if ( $categories = get_posts( $args ) ) {
            foreach ( $categories as $category ) {
                ( int ) $catlist[ $category->ID ] = $category->post_title;
            }
        }
        else {
            ( int ) $catlist[ '0' ] = esc_html__( 'No contact From 7 form found', 'rodio-core' );
        }

        return $catlist;
    }

}