<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package rodio
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

$class = 'col-lg-8 offset-lg-2';
if ( is_page() ) {
	$class = 'col-lg-10 offset-lg-1';
}


$logged_in_form = [
	'comment_field' => '
	<div class="comment-form">
		<div class="row">
			<div class="col">
				<div class="textarea-group single">
					<div class="form-floating">
						<textarea 
						required
						class="form-control" 
						placeholder="' . __('Write your comment *', 'rodio') . '" 
						name="comment"
						id="comment"
						></textarea>
						<label for="comment">' . __('Write your comment *', 'rodio') . '</label>
					</div>
				</div>
			</div>
		</div>
	</div>
	',
	'title_reply' => wp_kses( '<span class="heading">' . __('Post a comment.', 'rodio') . '</span>' , 'post' ),
	'comment_notes_before' => '',
	'cancel_reply_link' => esc_html__('CANCEL', 'rodio'),
	'label_submit' => esc_html__('Submit', 'rodio'),
	'submit_field' => '
	<div class="row form-submit-row">
		<div class="col-lg-6">
			<p class="form-submit button">%1$s %2$s</p>
		</div>
		<div class="col-lg-6 cancel"></div>
	</div>'
];

$logged_out_form = [
	'comment_field' => '',
	'title_reply' => wp_kses( '<span class="heading">' . __('Post a comment.', 'rodio') . '</span>' , 'post' ),
	'comment_notes_before' => '',
	'cancel_reply_link' => esc_html__('CANCEL', 'rodio'),
	'label_submit' => esc_html__('Submit', 'rodio'),
	'submit_field' => '
	<div class="row form-submit-row">
		<div class="col-lg-6">
			<p class="form-submit button">%1$s %2$s</p>
		</div>
		<div class="col-lg-6 cancel"></div>
	</div>'
];

?>

<!-- comments - start -->
<?php if ( have_comments() ) : ?>
<div class="comments-area">
	<div class="comments-area-wrapper">
		<div class="container">
			<div class="row">
				<div class="<?php echo esc_attr( $class ); ?>">
				
					<div class="heading comments-title">
						<?php
							$rodio_comment_count = get_comments_number();
							if ( '1' === $rodio_comment_count ) {
								echo esc_html( $rodio_comment_count . __( ' comment', 'rodio' ) );
							} else {
								echo esc_html( $rodio_comment_count . __( ' comments', 'rodio' ) );
							}
						?>
					</div><!-- .comments-title -->

					<div class="comment-list">
						<?php
							wp_list_comments(
								array(
									'short_ping' => true,
									'callback' => 'rodio_comment_style',
									'style' => 'div'
								)
							);
						?>
					</div><!-- .comment-list -->

					<?php the_comments_navigation(); ?>
				</div>
			</div>
		</div>
	</div>
</div>
<?php endif; // Check for have_comments(). ?>
<!-- comments - end -->

<!--
comment form - start
-->
<div class="comment-form--wrapper <?php echo esc_attr( ! have_comments() ? 'no-comments' : '' ); ?>  <?php echo esc_attr( is_user_logged_in() ? 'logged-in-form': '' ); ?>">
    <div class="container">
        <div class="row">
            <div class="<?php echo esc_attr( $class ); ?>">
                <?php
					comment_form(
						is_user_logged_in() ?
						$logged_in_form :
						$logged_out_form
					);
                ?>
            </div>
        </div>
    </div>
</div>
<!--
comment form - end
-->