<?php
/**
 * rodio functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package rodio
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function rodio_setup() {
	/*
		* Make theme available for translation.
		* Translations can be filed in the /languages/ directory.
		* If you're building a theme based on rodio, use a find and replace
		* to change 'rodio' to the name of your theme in all the template files.
		*/
	load_theme_textdomain( 'rodio', get_template_directory() . '/inc/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
		* Let WordPress manage the document title.
		* By adding theme support, we declare that this theme does not use a
		* hard-coded <title> tag in the document head, and expect WordPress to
		* provide it for us.
		*/
	add_theme_support( 'title-tag' );

	/*
		* Enable support for Post Thumbnails on posts and pages.
		*
		* @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		*/
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'default-menu' => esc_html__( 'Default Menu', 'rodio' ),
		)
	);

	/*
		* Switch default core markup for search form, comment form, and comments
		* to output valid HTML5.
		*/
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		)
	);
	
	add_image_size('rodio-post-thumbnail-size', 370, 296, true);
	add_image_size('rodio-recent-post-thumbnail-size', 70, 70, true);
	add_image_size('rodio-post-detail-thumbnail-size', 970, 446, true);
	add_image_size('rodio-project-thumbnail-size', 561, 456, true);
	add_image_size('rodio-project-detail-thumbnail-size', 970, 457, [ 'center', 'top' ]);
	add_image_size('rodio-slider-1', 970, 478, true);

	remove_theme_support( 'widgets-block-editor' );
}
add_action( 'after_setup_theme', 'rodio_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function rodio_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'rodio_content_width', 640 );
}
add_action( 'after_setup_theme', 'rodio_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function rodio_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar', 'rodio' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Widgets added here will be displayed on the blogs page.', 'rodio' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Search Sidebar', 'rodio' ),
			'id'            => 'search_sidebar',
			'description'   => esc_html__( 'Widgets added here will be displayed on the search page.', 'rodio' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Archives Sidebar', 'rodio' ),
			'id'            => 'archive_sidebar',
			'description'   => esc_html__( 'Widgets added here will be displayed on the archives page.', 'rodio' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'rodio_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function rodio_scripts() {
	wp_enqueue_style( 'rodio-fonts', rodio_fonts_url(), array(), false, 'all' );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/inc/assets/css/bootstrap.min.css', array(), '5.1.3' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/inc/assets/css/font-awesome.min.css', array(), '6.1.1' );
	wp_enqueue_style( 'swiper', get_template_directory_uri() . '/inc/assets/css/swiper-bundle.min.css', array(), '8.0.3' );
	wp_enqueue_style( 'overlay-scrollbars', get_template_directory_uri() . '/inc/assets/css/OverlayScrollbars.min.css', array(), '1.13.0' );
	wp_enqueue_style( 'rodio-style', get_stylesheet_uri(), array('bootstrap'), _S_VERSION );

	wp_register_style( 'glightbox', get_template_directory_uri() . '/inc/assets/css/glightbox.min.css', array(), '3.2.0' );

	wp_register_script( 'isotope', get_template_directory_uri() . '/inc/assets/js/plugins/isotope.pkgd.min.js', array(), '3.0.6', true );
	wp_register_script( 'glightbox', get_template_directory_uri() . '/inc/assets/js/plugins/glightbox.min.js', array(), '3.2.0', true );

	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/inc/assets/js/plugins/bootstrap.min.js', array(), '5.1.3', true );
	wp_enqueue_script( 'swiper', get_template_directory_uri() . '/inc/assets/js/plugins/swiper-bundle.min.js', array(), '8.0.3', false );
	wp_enqueue_script( 'gsap', get_template_directory_uri() . '/inc/assets/js/plugins/gsap.min.js', array(), '3.9.1', false );
	wp_enqueue_script( 'masonry', get_template_directory_uri() . '/inc/assets/js/plugins/masonry.pkgd.min.js', array(), '4.2.2', false );
	wp_enqueue_script( 'overlay-scrollbars', get_template_directory_uri() . '/inc/assets/js/plugins/OverlayScrollbars.min.js', array(), '1.13.0', false );	
	wp_enqueue_script( 'rodio-main', get_template_directory_uri() . '/inc/assets/js/main.min.js', array(), null, true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'rodio_scripts' );

if (!function_exists('rodio_fonts_url')){	
	/**
	 * get the url for the theme font
	 *
	 * @return string
	 */
	function rodio_fonts_url() {
	  $fonts_url = '';
	  $font     = '';
	  $subsets   = 'latin,latin-ext';
	  /* translators: If there are characters in your language that are not supported by Spartan, translate this to 'off'. Do not translate into your own language. */
	  $font = 'Spartan:500,600,700&display=swap';
	
	  if ( $font ) {
		  $fonts_url = add_query_arg( array(
			  'family' =>  $font,
			  'subset' =>  $subsets,
		  ), '//fonts.googleapis.com/css' );
	  }
	  return esc_url_raw($fonts_url);
	}
}


if (!function_exists('rodio_kses_allowed_html')) {	
	/**
	 * get the allowed tags for a certain context
	 *
	 * @param  mixed $tags
	 * @param  mixed $context
	 * @return mixed
	 */
	function rodio_kses_allowed_html($tags, $context) {
	  switch($context) {
		case 'general': 
		  $tags = wp_kses_allowed_html('post');
		  return $tags;
		case 'elementor-general': 
			$tags = wp_kses_allowed_html('post');
			unset( $tags['p'] );
			$tags = array_merge( $tags, [
				'input' => [
					'type'	=> [],
					'name'	=> [],
					'value'	=> [],
					'checked'	=> [],
				]
			] );
			return $tags;
		case 'elementor-template': 
				$tags = wp_kses_allowed_html('post');
				$tags = array_merge( $tags, [
					'style' => [],
					'form' => [
						'name' => true,
						'class' => true,
						'id' => true,
						'rel' => true,
						'action' => true,
						'enctype' => true,
						'method' => true,
						'novalidate' => true,
						'target' => true
					],
					'button' => [
						'autofocus' => true,
						'autocomplete' => true,
						'disabled' => true,
						'form' => true,
						'formaction' => true,
						'formenctype' => true,
						'formmethod' => true,
						'formnovalidate' => true,
						'formtarget' => true,
						'name' => true,
						'type' => true,
						'value' => true,
						'class' => true,
						'id' => true
					],
					'input' => [
						'class' => true,
						'id' => true,
						'name' => true,
						'value' => true,
						'type' => true,
						'placeholder' => true,
						'required' => true,
						'width' => true,
						'title' => true,
						'tabindex' => true,
						'step' => true,
						'src' => true,
						'size' => true,
						'readonly' => true,
						'pattern' => true,
						'multiple' => true,
						'minlength' => true,
						'maxlength' => true,
						'min' => true,
						'max' => true,
						'list' => true,
						'inputmod' => true,
						'height' => true,
						'formtarget' => true,
						'formnovalidate' => true,
						'formmethod' => true,
						'formenctype' => true,
						'formaction' => true,
						'form' => true,
						'disabled' => true,
						'dirname' => true,
						'checked' => true,
						'capture' => true,
						'autofocus' => true,
						'autocomplete' => true,
						'alt' => true,
						'accept' => true
					],
					'textarea' => [
						'class' => true,
						'id' => true,
						'name' => true,
						'placeholder' => true,
						'required' => true,
						'autocomplete' => true,
						'autocorrect' => true,
						'autofocus' => true,
						'cols' => true,
						'disabled' => true,
						'form' => true,
						'maxlength' => true,
						'minlength' => true						
					],
					'label' => [
						'for' => true
					],
					'svg'   => [
						'class' => true,
						'aria-hidden' => true,
						'aria-labelledby' => true,
						'role' => true,
						'xmlns' => true,
						'width' => true,
						'height' => true,
						'viewbox' => true,
					],
					'g'     => [ 'fill' => true ],
					'title' => [ 'title' => true ],
					'path'  => [ 'd' => true, 'fill' => true,  ],

				] );
				return $tags;
		case 'wysiwyg-heading-removal':
			$tags = wp_kses_allowed_html('post');
			unset( $tags['h1'] );
			unset( $tags['h2'] );
			unset( $tags['h3'] );
			unset( $tags['h4'] );
			unset( $tags['h5'] );
			unset( $tags['h6'] );
			return $tags;
		case 'br-allowed':
		  $tags = array(
			'br' => array()
		  );
		  return $tags;
		case 'anchor-allowed':
		  $tags = array(
			'a' => array(
			  'href' => array(),
			  'class' => array(),
			  'id' => array()
			)
		  );
		  return $tags;
		default: 
		  return $tags;
	  }
	}
}
add_filter( 'wp_kses_allowed_html', 'rodio_kses_allowed_html', 10, 2);

function rodio_channel_nav_class( $classes, $item, $args, $depth ) {

	$is_swiper_container = in_array( 'swiper-container', explode( ' ', $args->container_class ) );

	if ( ! $is_swiper_container ) return $classes;

	if ( $depth == 0 ) {
		$classes[] = "swiper-slide";
	}
    return $classes;
}
add_filter( 'nav_menu_css_class' , 'rodio_channel_nav_class' , 10, 4 );


/**
 * Allow SVG
 */
if (!function_exists('rodio_check_filetype_and_ext')){
	function rodio_check_filetype_and_ext($data, $file, $filename, $mimes) {
	
	  global $wp_version;
	  if ( $wp_version !== '4.7.1' ) {
		 return $data;
	  }
	
	  $filetype = wp_check_filetype( $filename, $mimes );
	
	  return [
		  'ext'             => $filetype['ext'],
		  'type'            => $filetype['type'],
		  'proper_filename' => $data['proper_filename']
	  ];
	}
}
add_filter( 'wp_check_filetype_and_ext', 'rodio_check_filetype_and_ext', 10, 4 );


if (!function_exists('rodio_cc_mime_types')){
	function rodio_cc_mime_types( $mimes ){
	  $mimes['svg'] = 'image/svg+xml';
	  return $mimes;
	}
}
add_filter( 'upload_mimes', 'rodio_cc_mime_types' );
	

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/misc/template-functions.php';

/**
 * Comments utilities
 */
require get_template_directory() . '/inc/misc/comments-util.php';

/**
 * elementor widgets.
 */
require get_template_directory() . '/inc/elementor-widgets/elementor-init.php';

/**
 * installation
 */
require get_template_directory() . '/inc/installation/install-init.php';

/**
 * project ajax
 */
require get_template_directory() . '/inc/misc/project-ajax.php';

/**
 * ACF select population
 */
require get_template_directory() . '/inc/misc/acf.php';