<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package rodio
 */
	global $rodio_opt;
	
	if ( !class_exists( 'Redux' ) ) {
		$rodio_opt = [];
		$rodio_opt['404_page_header_desktop'] = 'default';
		$rodio_opt['404_page_header_mobile'] = 'default';
		$rodio_opt['search_page_header_desktop'] = 'default';
		$rodio_opt['search_page_header_mobile'] = 'default';
		$rodio_opt['preloader_switch'] = true;
	} else {
		global $rodio_opt;
	}

	$header_id = 'default';
	$header_mobile_id = 'default';
	if ( function_exists( 'get_field' ) ) {
		$header_id = ( ! empty( get_field( 'header_desktop' ) ) ) ? get_field( 'header_desktop' ) : 'default';
		$header_mobile_id = ( ! empty( get_field( 'header_mobile' ) ) ) ? get_field( 'header_mobile' ) : 'default';
	}

	if ( is_404() && class_exists( 'Redux' ) ) {
		$header_id = ( ! empty( $rodio_opt['404_page_header_desktop'] ) ) ? $rodio_opt['404_page_header_desktop'] : 'default';
		$header_mobile_id = ( ! empty( $rodio_opt['404_page_header_mobile'] ) ) ? $rodio_opt['404_page_header_mobile'] : 'default';
	}

	if ( is_search() && class_exists( 'Redux' ) ) {
		$header_id = ( ! empty( $rodio_opt['search_page_header_desktop'] ) ) ? $rodio_opt['search_page_header_desktop'] : 'default';
		$header_mobile_id = ( ! empty( $rodio_opt['search_page_header_mobile'] ) ) ? $rodio_opt['search_page_header_mobile'] : 'default';
	}

	$scrollbar_class = ' enabled-sticky-nav';
	$header_body_class = 'header-default';
	if ( $header_id != 'default' ) {
		$header_body_class = 'header-custom';
	}

?>
<!doctype html>
<html <?php language_attributes();?>>
<head>
	<meta charset="<?php bloginfo('charset');?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head();?>
</head>



<body <?php body_class( [ $scrollbar_class, $header_body_class ] );?>>
<?php wp_body_open();?>

	<?php if ( $rodio_opt['preloader_switch'] ): ?>
	<div class="preloader">
		<div class="preloader-icon">
			<div class="preloader-icon-container">
				<span class="animated-preloader"></span>
			</div>
		</div>
	</div>
	<?php endif; ?>

	<div class="back-to-top">
		<div class="back-to-top-inner">
			<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 384 512"><path d="M363.9 330.7c-6.271 6.918-16.39 6.783-22.62 1.188L192 197.5l-149.3 134.4c-6.594 5.877-16.69 5.361-22.62-1.188C14.2 324.1 14.73 314 21.29 308.1l159.1-144c6.125-5.469 15.31-5.469 21.44 0l159.1 144C369.3 314 369.8 324.1 363.9 330.7z"/></svg>
		</div>
	</div>

	<div 
		class="main-wrapper"
		data-barba="container"
		data-barba-namespace="bn-<?php echo esc_attr( get_post_type() ); ?>-<?php the_ID(); ?>"
	>

	<?php
		// don't display the header if the post type is header and footer.
		if ( ! is_singular( 'header' ) && ! is_singular( 'footer' ) && ! is_singular( 'elementor_library' ) ):
	?>
		<div 
		class="
			header-wrapper 
			desktop 
			<?php echo esc_attr( ! empty( $header_id ) && $header_id == 'default' ? 'header-wrapper-default' : '' ); ?>
			"
		>
			<div class="header">
				<?php
				
					if ( ! empty( $header_id ) && $header_id == 'default' ) {
						// default navigation
						get_template_part( 'inc/template-parts/header/header', 'default' );
					} else if ( !empty( $header_id ) ) {
						// custom navigation
						get_template_part( 
							'inc/template-parts/header/header', 
							'custom', 
							[ 'header_id' => $header_id ] 
						);	
					}

				?>
			</div>
		</div>

		<div class="header-wrapper mobile">
			<div class="header">
				<?php
				
					if ( !empty( $header_mobile_id ) && $header_mobile_id == 'default' ) {
						// default navigation
						get_template_part( 'inc/template-parts/header/header', 'default' );
					} else if ( !empty( $header_mobile_id ) ) {
						// custom navigation
						get_template_part( 
							'inc/template-parts/header/header', 
							'custom', 
							[ 'header_id' => $header_mobile_id ] 
						);
					}

				?>
			</div>
		</div>
	<?php endif; ?>
