import "core-js/stable";
import "regenerator-runtime/runtime";

import { project_trigger } from './animations/project';
import { tab_handler, nav_select_handler } from './animations/tabs';
import { team_anim_handler } from './animations/team-members';
import { trigger_ib } from './animations/image-box';
import { offset_image, height_computer } from './components/image';
import { 
    nav_handler, 
    dropdown_switch,
    dropdown_leave,
    add_nav_arrow,
    add_top_nav_arrow,
    // create_back_element_wrapper, 
    // nav_back_handler,
    sm_mouseleave_handler,
    nav_slider_handler
} from './navigation/nav.js';
import { calculate_section_offset } from './components/section';
import { selectify } from './selectify/selectify';
import { hs1_handler, hs1_height_resize_handler } from './sliders/hero-slider-1';
import { hs2_handler } from './sliders/hero-slider-2';
import { masonry_handler } from './components/masonry';
import { init_io } from './observers/intersection';
import { hide_preloader, show_preloader } from './animations/preloader';
import { accordion_class_handler } from './components/accordion';
import { hamburger_handler } from './navigation/hamburger';
import { mob_dropdown_handler } from './navigation/mobile-nav';
import { create_back_element_wrapper } from './navigation/mobile-nav';
import { project_load_more_handler } from './components/project-ajax';
import { wrap_archive_year } from './components/archive-widget';
import { video_overlay_handler } from './components/video';

import { gallery_handler, gallery_layout_handler } from './gallery/handler';
import { lightbox_handler } from './components/lightbox';
import { back_to_top_handler } from './components/back-to-top';

import { wrap_tables } from './components/table';
import { comment_cancel_handler } from './components/comments';

import './scroll/init';



// default on scroll event
// scroll event for custom scrollbar is handled there. 
window.addEventListener('scroll', () => {
    if ( document.body.scrollEvents === undefined ) return;

    document.body.scrollEvents.forEach((func) => {
        func();
    })
})


const global_on_load = (e) => {
    
    offset_image();
    height_computer();

    // tab
    tab_handler(e.type);

    // navigation
    add_nav_arrow('.sub-menu .menu-item-has-children');
    add_nav_arrow('.navigation-menu.mobile > .menu-item-has-children');
    add_top_nav_arrow('.navigation-menu.desktop > .menu-item-has-children');

    // align sections to either side
    calculate_section_offset();

    // hero slider 1
    hs1_handler();

    // hero slider 2
    hs2_handler();

    // masonry
    masonry_handler();

    // intersection observer
    init_io();
        
    // accordion
    accordion_class_handler();

    // mobile navigation menu back init 
    create_back_element_wrapper();

    // archive widget
    wrap_archive_year();

    // gallery
    gallery_handler();

    // lightbox
    lightbox_handler();

    // wrap tables
    wrap_tables();

    // navigation slider
    nav_slider_handler();

    selectify('select');

    // preloader
    hide_preloader();

}

const elementor_load = () => {
    setTimeout(() => {
        if ( ! document.body.classList.contains('elementor-editor-active') ) return;
        elementorFrontend.hooks.addAction( 'frontend/element_ready/widget', function( $scope ) {   
            // hero slider 2
            if ( $scope[0].classList.contains('elementor-widget-rodio_hero_slider_2') ) {
                hs2_handler();
            }

            // masonry
            if ( $scope[0].classList.contains('elementor-widget-rodio_masonry') ) {
                masonry_handler();
            }

            if ( $scope[0].classList.contains('elementor-widget-rodio_image') ) {
                offset_image();
                // height_computer();
            }

            if ( $scope[0].classList.contains('elementor-widget-rodio_tabs') ) {
                tab_handler('load');
                selectify('.elementor-widget-rodio_tabs select')
            }

            if ( $scope[0].classList.contains('elementor-widget-rodio_gallery') ) {
                selectify('.elementor-widget-rodio_gallery select')
            }

        });
    });
}

// on window load
window.addEventListener( 'load', global_on_load);
window.addEventListener( 'load', elementor_load);


const preloader_handler = () => {
    // beforeunload event does not fire reliably on mobile devices
    // so the current solution is to avoid the animation on mobile devices
    let touchDevice = (navigator.maxTouchPoints || 'ontouchstart' in document.documentElement)
    if (touchDevice)
        return;
    // prevent preloader for phone and email links
    let active = document.activeElement;
    if ( 
        active.matches('a:is([href^="tel:"])') || 
        active.matches('a:is([href^="mailto:"])') ||
        active.matches('a:is([href^="#"])')
    ) 
        return;


    // preloader
    show_preloader();
}

// on window unload
window.addEventListener( 'beforeunload', preloader_handler);


// on window resize
window.addEventListener( 'resize', (e) => {
    offset_image();
    height_computer();

    // hero slider 1
    hs1_height_resize_handler();

    // align sections to either side
    calculate_section_offset();
    
    // tab
    tab_handler(e);
} );

// click event
document.addEventListener('click', (e) => {
    // image box
    // the image box should not be child of swiper-slide, because animation is handled
    // differently on the hero-slider-1.
    if ( e.target.closest('.image-box') && !e.target.closest('.swiper-slide') ) {
        trigger_ib(e.target.closest('.image-box'));
    }

    if ( e.target.closest('.elementor-widget-video') ) {
        video_overlay_handler( e.target.closest('.elementor-widget-video') );
    }

    
    // tab select
    if ( e.target.matches('.rodio-tabs-inner .selectify li') ) {
        nav_select_handler(e.target);
    }

    // team animation
    if ( e.target.closest('.team-member') ) {
        team_anim_handler(e.target.closest('.team-member'));
    }

    if ( e.target.closest('.hamburger-icon') || e.target.closest('.hamburger-overlay') ) {
        hamburger_handler(e);
    }

    if ( e.target.closest('.navigation-menu.mobile .back-button') ) {
        mob_dropdown_handler(e, true);
    }

    if ( e.target.parentNode.matches('.navigation-menu.mobile .menu-item-has-children') ) {
        mob_dropdown_handler(e);
    }

    if ( e.target.closest('.hamburger-close') ) {
        hamburger_handler(e);
    }

    if ( e.target.matches('.load-more-button') ) {
        project_load_more_handler(e);
    }

    if ( e.target.matches( '.gallery .filter a' ) ) {
        gallery_layout_handler(e);
    }

    if ( e.target.closest('.back-to-top') ) {
        back_to_top_handler(e);
    }

    if ( ! e.target.closest('.selectify') ) {
        let selects = document.querySelectorAll('.selectify.shown');
        selects.forEach(select => {
            select.classList.remove('shown');
        })
    }

    if ( e.target.matches('.comment-reply-link') ) {
        comment_cancel_handler(e);
    }

    if ( e.target.matches('a:is([href^="#"])') ) {
        e.preventDefault();
        let body = document.querySelector('body.custom-scrollbar');
        if ( body.scrollbar == null ) return;
        const el = document.querySelector(`${e.target.getAttribute('href')}`);
        body.scrollbar.scroll(el, 1000);
    }

});

// mouseenter event
document.body.addEventListener('mouseenter', function(e) {
    e.stopPropagation();

    let width = window.outerWidth;

    // project
    if ( e.target.matches('.project-single') && width >= 992 ) {
        project_trigger(e);
    }

    // navigation
    if ( e.target.matches('.navigation-menu.desktop > .menu-item-has-children') ) {
        nav_handler(e)
    }

}, true)

// mouseleave event
document.body.addEventListener('mouseleave', function(e) {
    e.stopPropagation();

    let width = window.outerWidth;

    // project
    if ( e.target.matches('.project-single') && width >= 992 ) {
        project_trigger(e);
    }

    if ( e.target.matches('.navigation-menu.desktop > .menu-item-has-children') ) {   
        nav_handler(e);
    }

    if ( e.target.matches('.navigation-menu.desktop .sub-menu .sub-menu') ) {
        sm_mouseleave_handler(e);
    }

}, true);

document.body.addEventListener('mouseover', (e) => {
    e.stopPropagation();
    if ( e.target.closest('.navigation-menu.desktop .sub-menu > .menu-item-has-children') ) {
        dropdown_switch(e)
    }
}, true);

document.body.addEventListener('mouseout', (e) => {
    if ( e.target.closest('.navigation-menu.desktop .sub-menu > .menu-item-has-children') ) {
        dropdown_leave(e)
    }
});