<?php

if ( !defined('ABSPATH') ) exit; // Exit if accessed directly

if ( !function_exists( 'rodio_slider' ) ):
function rodio_slider($id, $options) {
?>
    <script>
        'use strict';

        let el_<?php echo esc_html( $id ); ?> = document.querySelector('.<?php echo esc_html( 'slider-'.$id ); ?> .swiper-container');

        // options
        let options_<?php echo esc_html( $id ); ?> = <?php echo wp_json_encode( $options ); ?>

        // slider init
        el_<?php echo esc_html( $id ); ?>.swiper = new Swiper(
            '.<?php echo esc_html( 'slider-'.$id ); ?> .swiper-container',
            options_<?php echo esc_html( $id ); ?>
        )

    </script>
<?php
}
endif;

if ( !function_exists( 'rodio_slider_pagination' ) ) {
    function rodio_slider_pagination( $settings, $id ) {
        if ( $settings['rs_pagination'] != 'yes' ) return;
    ?>
        <div class="slider-pagination slider-pagination-<?php echo esc_attr( $id ); ?>"></div>
    <?php
    }
}

if ( !function_exists( 'rodio_slider_controls' ) ) {
    function rodio_slider_controls( $instance = null, $condition = [] ) {
        if ( $instance == null ) return;

        $instance->add_control(
            'rs_slides_per_view',
            [
                'label' => esc_html__( 'Slides per view', 'rodio' ),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 1,
                'condition' => $condition
            ]
        );
    
        $instance->add_control(
           'rs_navigation',
            [
                'label' => __( 'Slider navigation', 'rodio' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'yes', 'rodio' ),
                'label_off' => __( 'no', 'rodio' ),
                'return_value' => 'yes',
                'condition' => $condition
            ]
        );
      
        $instance->add_control(
            'rs_prev_icon',
            [
                'label' => __('Navigation previous icon', 'rodio'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'condition' => array_merge( ['rs_navigation' => 'yes'], $condition )
            ]
        );
      
        $instance->add_control(
            'rs_next_icon',
            [
                'label' => __('Navigation next icon', 'rodio'),
                'type' => \Elementor\Controls_Manager::ICONS,
                'condition' => array_merge( ['rs_navigation' => 'yes'], $condition )
            ]
        );

        $instance->add_control(
            'rs_pagination',
             [
                 'label' => __( 'Slider Pagination', 'rodio' ),
                 'type' => \Elementor\Controls_Manager::SWITCHER,
                 'label_on' => __( 'yes', 'rodio' ),
                 'label_off' => __( 'no', 'rodio' ),
                 'return_value' => 'yes',
                 'condition' => $condition
             ]
         );
          
        $instance->add_control(
            'rs_autoplay',
            [
                'label' => __( 'Slider autoplay', 'rodio' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'yes', 'rodio' ),
                'label_off' => __( 'no', 'rodio' ),
                'return_value' => 'yes',
                'condition' => $condition
            ]
        );
      
        $instance->add_control(
            'rs_autoplay_delay',
            [
                'label' => __( 'Delay', 'rodio' ),
                'description' => __('1000 represents 1 second', 'rodio'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'min' => 0,
                'max' => 60000,
                'step' => 500,
                'default' => 2000,
                'condition' => $condition
            ]
        );
      
        $instance->add_control(
            'rs_speed',
            [
              'label' => __( 'Speed', 'rodio' ),
              'description' => __('1000 represents 1 second', 'rodio'),
              'type' => \Elementor\Controls_Manager::NUMBER,
              'min' => 0,
              'max' => 60000,
              'step' => 500,
              'default' => 2000,
              'condition' => $condition
            ]
        );
      
        $instance->add_control(
            'rs_loop',
            [
              'label' => __( 'Slider loop', 'rodio' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
              'label_on' => __( 'yes', 'rodio' ),
              'label_off' => __( 'no', 'rodio' ),
              'return_value' => 'yes',
              'condition' => $condition        
            ]
        );
    }
}

if ( !function_exists( 'rodio_slider_options' ) ) {
    function rodio_slider_options( $settings, $id, $other = null ) {

        if ( empty( $settings ) ) return;

        $options = [
            'loop' => $settings['rs_loop'] ? true : false,
            'speed' =>  $settings['rs_speed'],
            'slidesPerView' => $settings['rs_slides_per_view'],
            'spaceBetween' => 0,
            'resizeObserver' => true
        ];

        // slider autoplay
        if ( $settings['rs_autoplay'] == 'yes' ) {
            $delay_arr = [
                'autoplay' => [
                    'delay' => $settings['rs_autoplay_delay'],
                    'disableOnInteraction' => false
                ]
            ];
            $options = array_merge( $options, $delay_arr );
        }
    
        // slider navigation
        if ( $settings['rs_navigation'] == 'yes' && !empty( $id ) ) {
            $navigation = [
                'navigation' => [
                    'nextEl' => '.slider-nav-'.$id.' .slider-nav-next',
                    'prevEl' => '.slider-nav-'.$id.' .slider-nav-prev',
                ]
            ];
            $options = array_merge( $options, $navigation );
        }

        // slider pagination
        if ( !empty( $settings['rs_pagination'] ) && $settings['rs_pagination'] == 'yes' && !empty( $id ) ) {
            $pagination = [
                'pagination' => [
                    'el' => '.slider-pagination-' . $id,
                    'type' => 'bullets',
                ]
            ];
            $options = array_merge( $options, $pagination );
        }

        

        if ( $other != null )
            $options = array_merge( $options, $other );
        
        return $options;
    }
}

if ( !function_exists( 'rodio_slide_nav_styles' ) ) {
    function rodio_slide_nav_styles( $instance ) {
        if ( empty( $instance ) ) return;

        $instance->start_controls_section(
            'rs_nav_styles',
            [
                'label' => __( 'Navigation', 'rodio' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [ 'rs_navigation' => 'yes' ]
            ]
        );

        $instance->add_control(
			'rs_nav_icon_size',
			[
				'label' => esc_html__( 'Size', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .slider-nav-btn .icon' => 'font-size: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .slider-nav-btn .icon-svg' => 'height: {{SIZE}}{{UNIT}};',
				],
                'condition' => [ 'rs_navigation' => 'yes' ]
			]
		);

        $instance->start_controls_tabs( 'rs_nav_tabs' );

        $instance->start_controls_tab(
            'rs_nav_normal',
            [
                'label' => esc_html__( 'Normal', 'rodio' ),
                'condition' => [ 'rs_navigation' => 'yes' ]
            ]
        );

        $instance->add_control(
			'rs_nav_normal_icon_color',
			[
				'label' => esc_html__( 'Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-nav-btn .icon' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .slider-nav-btn .icon-svg' => 'fill: {{VALUE}};',
				],
                'condition' => [ 'rs_navigation' => 'yes' ]
			]
		);

        $instance->add_control(
			'rs_nav_normal_icon_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-nav-btn' => 'background-color: {{VALUE}};',
				],
                'condition' => [ 'rs_navigation' => 'yes' ]
			]
		);

        $instance->end_controls_tab();

        $instance->start_controls_tab(
            'rs_nav_hover',
            [
                'label' => esc_html__( 'Hover', 'rodio' ),
                'condition' => [ 'rs_navigation' => 'yes' ]
            ]
        );

        $instance->add_control(
			'rs_nav_hover_icon_color',
			[
				'label' => esc_html__( 'Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-nav-btn:hover .icon' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .slider-nav-btn:hover .icon-svg' => 'fill: {{VALUE}};',
				],
                'condition' => [ 'rs_navigation' => 'yes' ]
			]
		);

        $instance->add_control(
			'rs_nav_hover_icon_bg_color',
			[
				'label' => esc_html__( 'Background Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-nav-btn::after' => 'background-color: {{VALUE}};',
				],
                'condition' => [ 'rs_navigation' => 'yes' ]
			]
		);

        $instance->end_controls_tab();

        $instance->end_controls_tabs();

        $instance->end_controls_section();

    }
}

if ( !function_exists( 'rodio_slide_pagination_styles' ) ) {
    function rodio_slide_pagination_styles( $instance ) {
        if ( empty( $instance ) ) return;

        $instance->start_controls_section(
            'rs_pagination_styles',
            [
                'label' => __( 'Pagination', 'rodio' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [ 'rs_pagination' => 'yes' ]
            ]
        );

        $instance->add_control(
			'rs_pagination_icon_size',
			[
				'label' => esc_html__( 'Size', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'rem' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .slider-pagination .swiper-pagination-bullet' => 
                    'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
				],
                'condition' => [ 'rs_pagination' => 'yes' ]
			]
		);

        $instance->start_controls_tabs( 'rs_pagination_tabs' );

        $instance->start_controls_tab(
            'rs_pagination_normal',
            [
                'label' => esc_html__( 'Normal', 'rodio' ),
                'condition' => [ 'rs_pagination' => 'yes' ]
            ]
        );

        $instance->add_control(
			'rs_pagination_normal_icon_color',
			[
				'label' => esc_html__( 'Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-pagination .swiper-pagination-bullet:not(.swiper-pagination-bullet-active)' => 
                    'background-color: {{VALUE}};'
				],
                'condition' => [ 'rs_pagination' => 'yes' ]
			]
		);

        $instance->end_controls_tab();

        $instance->start_controls_tab(
            'rs_pagination_hover',
            [
                'label' => esc_html__( 'Hover', 'rodio' ),
                'condition' => [ 'rs_pagination' => 'yes' ]
            ]
        );

        $instance->add_control(
			'rs_pagination_hover_icon_color',
			[
				'label' => esc_html__( 'Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-pagination .swiper-pagination-bullet:hover' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .slider-pagination .swiper-pagination-bullet-active:hover' => 'background-color: {{VALUE}};'
				],
                'condition' => [ 'rs_pagination' => 'yes' ]
			]
		);

        $instance->end_controls_tab();

        $instance->end_controls_tabs();

        $instance->end_controls_section();

    }
}

if ( !function_exists( 'rodio_heading_data_controls' ) ) {
    function rodio_heading_data_controls( $instance = null, $condition = [] ) {
        if ( $instance == null ) return;

        $instance->add_control(
            'r_heading_control',
            [
                'label' => esc_html__('Heading', 'rodio'),
                'type' => \Elementor\Controls_Manager::WYSIWYG,
                'default' => '',
                'condition' => $condition
            ]
        );

    }
}

if ( !function_exists( 'rodio_heading_style_controls' ) ) {
    function rodio_heading_style_controls( $instance = null, $condition = [] ) {
        if ( $instance == null ) return;

        $instance->add_control(
            'r_heading_preset',
            [
              'label' => esc_html__( 'preset', 'rodio' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'default' => 'normal',
              'options' => [
                'small'  => esc_html__( 'small', 'rodio' ),
                'large'  => esc_html__( 'large', 'rodio' ),
                'normal' => esc_html__( 'normal', 'rodio' ),
              ],
              'condition' => $condition
            ]
        );
    
        $instance->add_control(
            'r_heading_preset_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
                'condition' => $condition
            ]
        );
      
        $instance->add_responsive_control(
            'r_heading_align',
          [
            'label'         => esc_html__( 'Alignment', 'rodio' ),
            'type'          => \Elementor\Controls_Manager::CHOOSE,
            'options'       => [
                'text-align: left;'      => [
                    'title'=> esc_html__( 'Left', 'rodio' ),
                    'icon' => 'eicon-text-align-left',
                ],
                'margin-left: auto; margin-right: auto; text-align: center;'    => [
                    'title'=> esc_html__( 'Center', 'rodio' ),
                    'icon' => 'eicon-text-align-center',
                ],
                'margin-left: auto; text-align: right;'     => [
                    'title'=> esc_html__( 'Right', 'rodio' ),
                    'icon' => 'eicon-text-align-right',
                ],
            ],
            'default'       => 'text-align: left;',
            'selectors'     => [ 
                '{{WRAPPER}} .heading' => '{{VALUE}}',
                '{{WRAPPER}} .heading::after' => '{{VALUE}}',
            ],
            'condition' => $condition
          ]
        );
    
        $instance->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'r_heading_type',
                'label' => esc_html__('Heading', 'rodio'),
                'selector' => '{{WRAPPER}} .heading',
                'condition' => $condition
            ]
        );
    
        $instance->add_control(
            'r_heading_color',
            [
                'label' => esc_html__('Color', 'rodio'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .heading' => 'color : {{VALUE}}'
                ],
                'condition' => $condition
            ]
        );
    
        $instance->end_controls_section();
    
        $instance->start_controls_section(
            'r_heading_bar_style',
            [
                'label' => esc_html__('Bar', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => $condition
            ]
        );
    
        $instance->add_control(
            'r_heading_bar_color',
            [
                'label' => esc_html__('Color', 'rodio'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .heading::after' => 'background-color : {{VALUE}}'
                ],
                'condition' => $condition
            ]
        );
    
        $instance->add_control(
            'r_heading_bar_width',
            [
                'label' => esc_html__( 'Width', 'rodio' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'rem', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                    'rem' => [
                        'min' => 0,
                        'max' => 100,
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .heading::after' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => $condition
            ]
        );
    
        $instance->add_control(
            'r_heading_bar_height',
            [
                'label' => esc_html__( 'Height', 'rodio' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'rem', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                    'rem' => [
                        'min' => 0,
                        'max' => 100,
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .heading::after' => 'height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => $condition
            ]
        );

    }
}

if ( !function_exists( 'rodio_get_elementor_templates' ) ) {
    function rodio_get_elementor_templates() {
        $templates = \Elementor\Plugin::instance()->templates_manager->get_source( 'local' )->get_items();

        if ( empty( $templates ) ) {
            return [ 
                '0' => __( 'There are no templates', 'rodio' ) 
            ];
        }

        $template_lists = [ 
            '0' => __( 'Select Template', 'rodio' ) 
        ];

        if ( is_array( $template_lists ) ) {
            foreach ( $templates as $template ) {
                $template_lists[ $template['template_id'] ] = $template['title'] . ' (' . $template['type'] . ')';
            }
        }

        return $template_lists;
    }
}

if ( !function_exists( 'rodio_render_icon' ) ) {
    function rodio_render_icon( $icon ) {

        // default next icon
        if ( !is_array( $icon ) && $icon == 'default-next' ) {
            ?>
                <span class="icon-svg icon">
                    <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 512"><path d="M219.9 266.7L75.89 426.7c-5.906 6.562-16.03 7.094-22.59 1.188c-6.918-6.271-6.783-16.39-1.188-22.62L186.5 256L52.11 106.7C46.23 100.1 46.75 90.04 53.29 84.1C59.86 78.2 69.98 78.73 75.89 85.29l144 159.1C225.4 251.4 225.4 260.6 219.9 266.7z"/></svg>
                </span>
            <?php
            return;
        }

        // default previous icon
        if ( !is_array( $icon ) && $icon == 'default-prev' ) {
            ?>
                <span class="icon-svg icon">
                    <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 512"><path d="M203.9 405.3c5.877 6.594 5.361 16.69-1.188 22.62c-6.562 5.906-16.69 5.375-22.59-1.188L36.1 266.7c-5.469-6.125-5.469-15.31 0-21.44l144-159.1c5.906-6.562 16.03-7.094 22.59-1.188c6.918 6.271 6.783 16.39 1.188 22.62L69.53 256L203.9 405.3z"/></svg>
                </span>
            <?php
            return;
        }

        // render icon from class
        if ( !is_array( $icon ) &&  !empty( $icon ) ) {
            ?>
                <i class="<?php echo esc_attr( $icon ) ?>"></i>
            <?php
            return;
        }

        $is_svg = $icon['library'] == 'svg';

        if ( $is_svg ) {
            echo wp_kses('<span class="icon-svg icon">', 'post');
        }
        
        \Elementor\Icons_Manager::render_icon( 
            $icon, 
            [ 'aria-hidden' => 'true', 'class' => 'icon' ]
        );

        if ( $is_svg ) {
            echo wp_kses('</span>', 'post');
        }


    }
}

if ( !function_exists( 'rodio_get_nav_menu_names' ) ) {
    function rodio_get_nav_menu_names() {
        $data = get_terms( 'nav_menu', [ 'hide_empty' => true ] );
        $result = [];
        if ( is_array( $data ) || is_object( $data ) ) {
            foreach( $data as $obj ) {
                $result[ $obj->term_id ] = $obj->name;
            }
        }
        return $result;
    }
}