<?php


if ( !defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class RodioVideoMod {
    public static function init() {
        // data controls
        add_action( 
            'elementor/element/video/section_image_overlay/before_section_end', 
            [ __CLASS__, 'controls' ], 
            10, 
            2 
        );

        // style controls
        add_action( 
            'elementor/element/video/section_video_style/before_section_end', 
            [ __CLASS__, 'video_style_controls' ], 
            10, 
            2 
        );

        add_action( 
            'elementor/element/video/section_video_style/after_section_end', 
            [ __CLASS__, 'style_controls' ], 
            10, 
            2 
        );

        add_filter( 
            'elementor/widget/render_content', 
            [ __CLASS__, 'render_content' ], 
            10, 
            2
        );
    }

    private static function get_icon( $icon, $attributes = [], $tag = 'i' ) {
        if ( empty( $icon['library'] ) ) {
			return '';
		}

		$output = '';

		/**
		 * When the library value is svg it means that it's a SVG media attachment uploaded by the user.
		 * Otherwise, it's the name of the font family that the icon belongs to.
		 */
		if ( 'svg' === $icon['library'] ) {
			$output = 
            '<div class="icon icon-svg">' . 
                \Elementor\Icons_Manager::render_uploaded_svg_icon( $icon['value'] ) .
            '</div>';
		} else {
			$output = \Elementor\Icons_Manager::render_font_icon( $icon, $attributes, $tag );
		}

		return $output;
    }

    public static function render_content( $widget_content, $widget ) {

        if ( $widget->get_name() === 'video' ) {
            $settings = $widget->get_settings_for_display();
            $icon = $settings['rodio_video_icon'];
            $text = $settings['video_overlay_text'];
            

            // $split = explode( '<div class="elementor-custom-embed-play" role="button">', $widget_content );
            // $split[0] .= '<div class="elementor-custom-embed-play" role="button">';
            
            if ( ! empty( $text ) || ! empty( $icon ) ) {
                $widget_content .= '<div class="rodio-overlay-container">';
            }

            // add overlay text
            if ( !empty( $text ) ) {
                $widget_content .= '<div class="rodio-overlay-text"><span>' . $text . '</span></div>';
            }

            // add icon
            if ( !empty( $icon ) ) {
                $widget_content .= 
                '<div class="rodio-icon">
                    <div class="icon-box">
                        <div class="icon-box-inner">' . 
                            self::get_icon( 
                                $icon, 
                                [ 'aria-hidden' => 'true', 'class' => 'icon' ]
                            ) . 
                        '</div>
                    </div>
                </div>'; 
            }

            if ( ! empty( $text ) || ! empty( $icon ) ) {
                $widget_content .= '</div>';
            }

            // $widget_content = implode( '', $split );

            return $widget_content;

        }
        
        return $widget_content;
    }

    public static function controls( $instance ) {

        $instance->add_control(
			'rodio_counter_heading',
			[
				'label' => esc_html__( 'RODIO', 'rodio' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

        $instance->add_control(
			'video_overlay_text',
			[
				'label' => esc_html__( 'Overlay text', 'rodio' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'rows' => 10,
                'condition' => [
					'show_image_overlay' => 'yes',
					'image_overlay[url]!' => '',
				],
			]
		);

        $instance->add_control(
			'rodio_video_icon',
			[
				'label' => esc_html__( 'Icon', 'rodio' ),
				'type' => \Elementor\Controls_Manager::ICONS,
                'condition' => [
                    'show_play_icon' => 'yes',
					'show_image_overlay' => 'yes',
					'image_overlay[url]!' => '',
				],
			]
		);

    }

    public static function style_controls( $instance ) {

        $instance->start_controls_section(
            'r_video_styles',
            [
              'label' => esc_html__('RODIO: Video', 'rodio'),
              'tab' => \Elementor\Controls_Manager::TAB_STYLE
            ]
        );

        $instance->add_responsive_control(
			'r_video_width',
			[
				'label' => esc_html__( 'Width', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
                    'rem' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
                    '{{WRAPPER}}' => 'width: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .elementor-wrapper' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .elementor-widget-container' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $instance->add_responsive_control(
			'r_video_height',
			[
				'label' => esc_html__( 'Height', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
                    'rem' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
                    '{{WRAPPER}}' => 'height: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .elementor-wrapper' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .elementor-wrapper' => 'padding-bottom: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .elementor-widget-container' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $instance->end_controls_section();

        $instance->start_controls_section(
            'r_overlay_text_styles',
            [
              'label' => esc_html__('RODIO: Overlay text', 'rodio'),
              'tab' => \Elementor\Controls_Manager::TAB_STYLE
            ]
        );

        $instance->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'r_overlay_text_typo',
                'label' => esc_html__('Typography', 'rodio'),
                'selector' => '{{WRAPPER}} .rodio-overlay-text span',
            ]
        );

        $instance->add_control(
            'r_overlay_text_color',
            [
              'label' => esc_html__('Color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .rodio-overlay-text span' => 'color : {{VALUE}}'
              ]
              
            ]
        );

        $instance->add_responsive_control(
			'r_overlay_text_width',
			[
				'label' => esc_html__( 'Width', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
                    'rem' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .rodio-overlay-text' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $instance->add_control(
            'r_overlay_text_bg_color',
            [
              'label' => esc_html__('Background Color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .rodio-overlay-text span' => '--bg-color : {{VALUE}}'
              ]
              
            ]
        );


        $instance->add_responsive_control(
            'r_overlay_text_align',
            [
                'label'         => esc_html__( 'Text Alignment', 'rodio' ),
                'type'          => \Elementor\Controls_Manager::CHOOSE,
                'options'       => [
                    'left'      => [
                        'title'=> __( 'Left', 'rodio' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center'    => [
                        'title'=> __( 'Center', 'rodio' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right'     => [
                        'title'=> __( 'Right', 'rodio' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default'       => 'center',
                'selectors'     => [
                    '{{WRAPPER}} .rodio-overlay-text' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $instance->add_responsive_control(
            'r_vertical_content_alignment',
            [
                'label'         => esc_html__( 'Vertical Content Alignment', 'rodio' ),
                'type'          => \Elementor\Controls_Manager::CHOOSE,
                'options'       => [
                    'flex-start'      => [
                        'title'=> __( 'Left', 'rodio' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center'    => [
                        'title'=> __( 'Center', 'rodio' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'flex-end'     => [
                        'title'=> __( 'Right', 'rodio' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default'       => 'center',
                'selectors'     => [
                    '{{WRAPPER}} .rodio-overlay-container' => 'justify-content: {{VALUE}};',
                ],
            ]
        );

        $instance->add_responsive_control(
            'r_horz_content_alignment',
            [
                'label'         => esc_html__( 'Horizontal Content Alignment', 'rodio' ),
                'type'          => \Elementor\Controls_Manager::CHOOSE,
                'options'       => [
                    'flex-start'      => [
                        'title'=> __( 'Left', 'rodio' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center'    => [
                        'title'=> __( 'Center', 'rodio' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'flex-end'     => [
                        'title'=> __( 'Right', 'rodio' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default'       => 'center',
                'selectors'     => [
                    '{{WRAPPER}} .rodio-overlay-container' => 'align-items: {{VALUE}};',
                ],
            ]
        );

        $instance->add_responsive_control(
			'margin',
			[
				'label' => esc_html__( 'Margin', 'rodio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .rodio-overlay-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $instance->end_controls_section();

        rodio_get_icon_size_styles( $instance, esc_html__( 'RODIO: Icon size', 'rodio' ) );
        rodio_get_icon_position_styles( $instance, esc_html__( 'RODIO: Icon Position', 'rodio' ) );
        rodio_get_icon_main_styles( $instance, esc_html__( 'RODIO: Icon Style', 'rodio' ) );

    }

    public static function video_style_controls( $instance ) {
        $instance->add_control(
			'video_border_radius',
			[
				'label' => esc_html__( 'Border radius', 'rodio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .elementor-video' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .elementor-custom-embed-image-overlay' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
    }

}

RodioVideoMod::init();