<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

function rodio_get_projects_options( $instance = null ) {
    if ( $instance == null ) return;

    $instance->start_controls_section(
        'project_section',
        [
            'label' => __( 'Project Options', 'rodio' ),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]
    );

    $instance->add_control(
        'important_note',
        [
            'label' => esc_html__( 'Important Note', 'rodio' ),
            'type' => \Elementor\Controls_Manager::RAW_HTML,
            'raw' => '<p style="margin-top: 20px; line-height: normal;">' . __( 'You can customize these projects by going to the \'Projects\' (menu to the left) in the admin dashboard.', 'rodio' ) . '</p>'
        ]
    );

    $instance->add_control(
        'rodio_projects_number',
        [
            'label' => __( 'Projects per page', 'rodio' ),
            'type'  => \Elementor\Controls_Manager::NUMBER,
            'min'			=> -1,
            'default' => 3
        ]
    );

    $instance->add_control(
        'rodio_projects_order',
        [
            'label' => __( 'Order', 'rodio' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'DESC' => 'descending',
                'ASC' => 'ascending',
            ],
            'default' => 'DESC',
        ]
    );

    $instance->add_control(
        'rodio_projects_sort',
        [
            'label' => __( 'Sorting projects by', 'rodio' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'date' => 'date',
                'modified' => 'last modified date',
                'rand' => 'Random',
                'title' => 'title',
                'comment_count' => 'number of comments',
            ],
            'default' => 'date',
        ]
    );

    $instance->end_controls_section();
}

function rodio_get_projects_style( $instance = null ) {
    if ( $instance == null ) return;

    $instance->start_controls_section(
        'project_style',
        [
            'label' => esc_html__('Style', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        ]
    );

    $instance->add_control(
        'project_background_color',
        [
          'label' => esc_html__('Background color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .project-single .project-bg' => 'background-color : {{VALUE}}'
          ]
          
        ]
    );

    $instance->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
            'name' => 'project_categories_typo',
            'label' => esc_html__('Categories Typography', 'rodio'),
            'selector' => '{{WRAPPER}} .project-single .categories',
        ]
    );

    $instance->add_control(
        'project_categories_color',
        [
          'label' => esc_html__('Categories Color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .project-single .categories' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $instance->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
            'name' => 'project_title_typo',
            'label' => esc_html__('Title Typography', 'rodio'),
            'selector' => '{{WRAPPER}} .project-single h4',
        ]
    );

    $instance->add_control(
        'project_title_color',
        [
          'label' => esc_html__('Title Color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .project-single h4' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $instance->add_control(
        'project_icon_size',
        [
            'label' => esc_html__( 'Icon Size', 'rodio' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px', 'rem' ],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 1000,
                    'step' => 1,
                ],
                'rem' => [
                    'min' => 0,
                    'max' => 100,
                    'step' => 1,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .project-single .project-reveal' => 'font-size: {{SIZE}}{{UNIT}};',
            ],
        ]
    );

    $instance->add_control(
        'project_icon_color',
        [
          'label' => esc_html__('Icon Color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .project-single .project-reveal' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $instance->end_controls_section();

}
