<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class Accordion extends \Elementor\Widget_Base

{

    public function get_name()
    {
        return 'rodio_accordion';
    }

    public function get_title()
    {
        return esc_html__('Accordion', 'rodio');
    }

    public function get_icon()
    {
        return 'eicon-accordion';
    }

    public function get_categories()
    {
        return ['gfxpartner'];
    }

    protected function register_controls()
    {

        // heading content - start

        $this->start_controls_section(
            'r_accordion_content',
            [
                'label' => esc_html__('Content', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'r_accordion_keep_open',
            [
                'label' => esc_html__( 'Keep one open', 'rodio' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'rodio' ),
                'label_off' => esc_html__( 'No', 'rodio' ),
                'return_value' => 'keep-open',
                'default' => 'dont-keep-open',
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'r_accordion_active',
            [
                'label' => esc_html__( 'Active', 'rodio' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'rodio' ),
                'label_off' => esc_html__( 'No', 'rodio' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $repeater->add_control(
            'r_accordion_title',
            [
                'label' => esc_html__('Title', 'rodio'),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__('Type your title here', 'rodio'),
                'label_block' => true
            ]
        );

        $repeater->add_control(
            'r_accordion_content',
            [
                'label' => esc_html__('Content', 'rodio'),
                'type' => \Elementor\Controls_Manager::TEXTAREA,                
                'placeholder' => esc_html__('Type your content here', 'rodio'),
            ]
        );

        $this->add_control(
            'r_accordion_repeater',
            [
                'label' => __('Tabs', 'rodio'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => __('Tab', 'rodio'),
            ]
        );

        $this->end_controls_section();

        // heading content - end

        // heading style - start

        $this->start_controls_section(
            'general_style',
            [
                'label' => esc_html__('General', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'tab_heading_typo',
                'label' => esc_html__('Typography', 'rodio'),
                'selector' => '{{WRAPPER}} .accordion-button',
            ]
        );

        $this->add_responsive_control(
			'heading_padding',
			[
				'label' => esc_html__( 'Heading padding', 'rodio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .accordion-header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->add_responsive_control(
			'body_padding',
			[
				'label' => esc_html__( 'Body padding', 'rodio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .accordion-body' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->add_control(
            'body_txt_color',
            [
              'label' => esc_html__('Body text color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .accordion-item p' => 'color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
			'border_radius',
			[
				'label' => esc_html__( 'Border radius', 'rodio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .accordion-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .accordion-item:first-of-type' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .accordion-item:last-of-type' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->start_controls_tabs( 'accordion_style_tabs' );
    
        $this->start_controls_tab(
            'tab_normal',
            [
                'label' => esc_html__( 'Normal', 'rodio' ),
            ]
        );

        $this->add_control(
            'tab_bg_color',
            [
              'label' => esc_html__('Background color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .accordion-item:not(.shown)' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'tab_heading_color',
            [
              'label' => esc_html__('Heading color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .accordion-button.collapsed' => 'color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'tab_icon_bg_color',
            [
              'label' => esc_html__('Icon background color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .accordion-button.collapsed .icon' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'tab_icon_color',
            [
              'label' => esc_html__('Icon color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .accordion-button.collapsed .icon::before' => 'background-color : {{VALUE}};',
                '{{WRAPPER}} .accordion-button.collapsed .icon::after' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_active',
            [
                'label' => esc_html__( 'Active', 'rodio' ),
            ]
        );

        $this->add_control(
            'tab_bg_color_active',
            [
              'label' => esc_html__('Background color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .accordion-item.shown' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'tab_heading_color_active',
            [
              'label' => esc_html__('Heading color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .accordion-button:not(.collapsed)' => 'color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'tab_icon_bg_color_active',
            [
              'label' => esc_html__('Icon background color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .accordion-button:not(.collapsed) .icon' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'tab_icon_color_active',
            [
              'label' => esc_html__('Icon color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .accordion-button:not(.collapsed) .icon::before' => 'background-color : {{VALUE}};',
                '{{WRAPPER}} .accordion-button:not(.collapsed) .icon::after' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->end_controls_tab();


        $this->end_controls_tabs();

        $this->end_controls_section();

        // heading style - end

    }

    private function accordion_item( $item, $parent, $id ) {
        $settings = $this->get_settings_for_display();
        $active = $item['r_accordion_active'] == 'yes';
        $heading_id = 'accordion-heading-' . $id . rand();
        $collapse_id = 'accordion-collapse-' . $id . rand();
    ?>
        <div class="accordion-item <?php echo esc_attr( $active ? 'shown' : '' ) ?>">
            <h2 
                class="accordion-header" 
                id="<?php echo esc_attr( $heading_id ); ?>"
            >
                <button 
                    class="accordion-button <?php echo esc_attr( $settings['r_accordion_keep_open'] ); ?> <?php echo esc_attr( $active ? '' : 'collapsed' ) ?>" 
                    type="button" 
                    data-bs-toggle="collapse" 
                    data-bs-target="#<?php echo esc_attr( $collapse_id ); ?>" 
                    aria-expanded="<?php echo esc_attr( $active ? 'true' : 'false' ) ?>" 
                    aria-controls="<?php echo esc_attr( $collapse_id ); ?>"
                >
                    <span><?php echo esc_html( $item['r_accordion_title'] ); ?></span>
                    <span class="icon"></span>
                </button>
            </h2>
            <div 
                id="<?php echo esc_attr( $collapse_id ); ?>"
                class="accordion-collapse collapse <?php echo esc_attr( $active ? 'show' : '' ) ?>" 
                aria-labelledby="<?php echo esc_attr( $heading_id ); ?>" 
                data-bs-parent="#<?php echo esc_attr( $parent ); ?>"
            >
                <div class="accordion-body">
                    <p><?php echo esc_html( $item['r_accordion_content'] ); ?></p>
                </div>
            </div>
        </div>
    <?php
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();

        $parent = 'accordion-parent-' . $id;

    ?>
    <div class="accordion" id="<?php echo esc_attr( $parent ); ?>">
        <?php 
            if ( is_array( $settings['r_accordion_repeater'] ) || is_object( $settings['r_accordion_repeater'] ) ) {
                foreach ( $settings['r_accordion_repeater'] as $item ) {
                    $this->accordion_item( $item, $parent, $id );
                } 
            }
        ?>
    </div>
    <?php
}
}
