<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Button extends \Elementor\Widget_Base {

  public function get_name(){
    return 'rodio_button';
  }

  public function get_title() {
    return esc_html__('Button', 'rodio');
  }

  public function get_icon() {
    return 'eicon-button';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // button content -  start

    $this->start_controls_section(
      'button_content',
      [
        'label' => esc_html__('Content', 'rodio'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );


    $this->add_control(
        'button_text',
        [
        'label' => esc_html__('Text', 'rodio'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => ''
        ]
    );

    $this->add_control(
        'button_link',
        [
            'label' => esc_html__('Link', 'rodio'),
            'type' => \Elementor\Controls_Manager::URL,
        
        ]
    );

    $this->add_control(
      'button_icon',
      [
          'label' => __('Icon', 'rodio'),
          'type' => \Elementor\Controls_Manager::ICONS
      ]
    );

    $this->end_controls_section();

    // button content -  end

    // button style -  start

    $this->start_controls_section(
        'button_custom_style',
        [
          'label' => esc_html__('Style', 'rodio'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
            'name' => 'button_text',
            'label' => esc_html__('Text', 'rodio'),
            'selector' => '{{WRAPPER}} .button',
        ]
    );

    $this->add_responsive_control(
      'button_align',
      [
          'label'         => esc_html__( 'Alignment', 'rodio' ),
          'type'          => \Elementor\Controls_Manager::CHOOSE,
          'options'       => [
              'left'      => [
                  'title'=> __( 'Left', 'rodio' ),
                  'icon' => 'fa fa-align-left',
              ],
              'center'    => [
                  'title'=> __( 'Center', 'rodio' ),
                  'icon' => 'fa fa-align-center',
              ],
              'right'     => [
                  'title'=> __( 'Right', 'rodio' ),
                  'icon' => 'fa fa-align-right',
              ],
          ],
          'default'       => 'center',
          'selectors'     => [
              '{{WRAPPER}}' => 'text-align: {{VALUE}};',
          ],
      ]
    );

    $this->add_responsive_control(
			'width',
			[
				'label' => esc_html__( 'Width', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
          'rem' => [
            'min' => 0,
            'max' => 100
          ]
				],
				'selectors' => [
					'{{WRAPPER}} .button' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

    $this->start_controls_tabs( 'button_tabs' );
    
    $this->start_controls_tab(
        'button_normal',
        [
            'label' => esc_html__( 'Normal', 'rodio' ),
        ]
    );

    $this->add_control(
        'button_text_color',
        [
          'label' => esc_html__('Text color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .button' => 'color : {{VALUE}} !important; fill : {{VALUE}} !important;'
          ]
          
        ]
    );

    $this->add_control(
      'button_bg_color',
      [
        'label' => esc_html__('Background color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .button' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );


    $this->end_controls_tab();

    $this->start_controls_tab(
        'button_hover',
        [
            'label' => esc_html__( 'Hover', 'rodio' ),
        ]
    );

    $this->add_control(
        'button_text_color_hover',
        [
          'label' => esc_html__('Text hover color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .button:hover' => 'color : {{VALUE}} !important; fill : {{VALUE}} !important;'
          ]
          
        ]
    );

    $this->add_control(
      'button_bg_color_hover',
      [
        'label' => esc_html__('Background color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .button:hover' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_tab();

    $this->end_controls_tabs();  

    $this->end_controls_section();

    // button style -  end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();

    $target = $settings['button_link']['is_external'] ? ' target="_blank"' : '';
    $nofollow = $settings['button_link']['nofollow'] ? ' rel="nofollow"' : '';
    $url = !empty( $settings['button_link']['url'] ) ? ' href='.esc_url( $settings['button_link']['url'] ) : '';

    $this->add_render_attribute('button_attr', 'class', 'button');

    if ( $settings['button_link']['is_external'] )
      $this->add_render_attribute('button_attr', 'target', '_blank');

    if ( $settings['button_link']['nofollow'] )
      $this->add_render_attribute('button_attr', 'rel', 'nofollow');

    if ( !empty( $settings['button_link']['url'] ) )
      $this->add_render_attribute('button_attr', 'href', $settings['button_link']['url']);
 
  ?>
    <a <?php $this->print_render_attribute_string('button_attr');  ?>>
      <div class="button-inner">
        <span><?php echo esc_html( $settings['button_text'] ); ?></span>
        
        <?php
          // icon
          \Elementor\Icons_Manager::render_icon( 
            $settings['button_icon'], 
            [ 'aria-hidden' => 'true', 'class' => 'icon' ]
          ); 
        ?>
      </div>
    </a>
    <?php
  }
}
