<?php

if (!defined('ABSPATH')) {
    exit;
}
// Exit if accessed directly

class ClientSlider extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'rodio_client_slider';
    }

    public function get_title()
    {
        return __('Client Slider', 'rodio');
    }

    public function get_icon()
    {
        return 'fas fa-user-friends';
    }

    public function get_categories()
    {
        return ['gfxpartner'];
    }

    protected function register_controls()
    {

        // slides - start

        $this->start_controls_section(
            'cs_content',
            [
                'label' => __('Slides', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'cs_image',
            [
                'label' => __('Choose Image', 'rodio'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'cs_link',
            [
                'label' => __('Link', 'rodio'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('https://your-link.com', 'rodio'),
                'show_external' => true,
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => true,
                ],
            ]
        );

        $this->add_control(
            'cs_repeater',
            [
                'label' => __('Client slides', 'rodio'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => __('Client', 'rodio'),
            ]
        );

        $this->end_controls_section();

        // slides - end

        // slider options - start

        $this->start_controls_section(
            'cs_options_section',
            [
                'label' => __('Slider options', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        rodio_slider_controls($this);

        $this->end_controls_section();

        // slider options - end

        // heading content - start

        $this->start_controls_section(
            'heading_content',
            [
                'label' => esc_html__('Heading', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        rodio_heading_data_controls( $this );

        $this->end_controls_section();

        // heading content - end

        // heading style - start

        $this->start_controls_section(
            'heading_style',
            [
                'label' => esc_html__('Heading', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        rodio_heading_style_controls( $this );

        $this->end_controls_section();

        // heading style - end

        // content style - start

        get_rodio_client_styles( $this );

        // content style - end

        // slider nav - start

        rodio_slide_nav_styles( $this );

        // slider nav - end

        // slider nav - start

        rodio_slide_pagination_styles( $this );

        // slider nav - end

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();

        // options for the slider
        $options = rodio_slider_options($settings, $id, 
            [
                'spaceBetween' => 30,
                'breakpoints' => [
                    '0' => [
                        'slidesPerView' => 1,
                        'centeredSlides' => true
                    ],
                    '500' => [
                        'slidesPerView' => 1.2,
                        'centeredSlides' => true
                    ],
                    '992' => [
                        'slidesPerView' => $settings['rs_slides_per_view'],
                        'centeredSlides' => false
                    ]
                ]
            ]
        );

        // main class list
        $class_list = [
            'slider',
            'client-slider',
            'slider-' . $id,
        ];

        ?>
    <div class="<?php echo esc_html(implode(' ', $class_list)); ?>">
        <!-- header - start -->
        <?php
            get_template_part(
                '/inc/template-parts/elementor/slider',
                'header',
                array(
                    'settings' => $settings,
                    'id' => $id,
                )
            );
        ?>
        <!-- header - end -->
        <!-- slider - start -->
        <div class="row">
            <div class="col-12">
                <div class="swiper-container">
                    <div class="swiper-wrapper">
                        <?php
                            if ( is_array( $settings['cs_repeater'] ) || is_object( $settings['cs_repeater'] ) ):
                            foreach ( $settings['cs_repeater'] as $item ):
                            $target = $item['cs_link']['is_external'] ? ' target="_blank"' : '';
                            $nofollow = $item['cs_link']['nofollow'] ? ' rel="nofollow"' : '';
                        ?>
	                            <!-- slide - start -->
	                            <div class="swiper-slide">
	                                <div class="client-slide">
	                                    <?php if (!empty($item['cs_link']['url'])): ?>
	                                        <a
	                                            href="<?php echo esc_url($item['cs_link']['url']); ?>"
	                                            class="client-image"
	                                            <?php echo esc_attr($target); ?>
	                                            <?php echo esc_attr($nofollow); ?>
	                                        >
	                                    <?php endif;?>

                                        <?php
                                            echo
                                            \Elementor\Group_Control_Image_Size::get_attachment_image_html(
                                                $item,
                                                'full',
                                                'cs_image'
                                            );
                                        ?>

                                    <?php if (!empty($item['cs_link']['url'])): ?>
                                        </a>
                                    <?php endif;?>
                                </div>
                            </div>
                            <!-- slide - end -->
                        <?php endforeach; endif; ?>
                    </div>
                </div>
            </div>
        </div>
        <!-- slider - end -->
    </div>
    <?php
rodio_slider($id, $options);
    }
}
