<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Gallery extends \Elementor\Widget_Base {

    public function get_name(){
        return 'rodio_gallery';
    }

    public function get_title() {
        return esc_html__('Gallery', 'rodio');
    }

    public function get_icon() {
        return 'eicon-gallery-masonry';
    }

    public function get_categories() {
        return ['gfxpartner'];
    }

    public function get_script_depends() {
		return [ 'isotope', 'glightbox' ];
	}

    public function get_style_depends() {
		return [ 'glightbox' ];
	}

    protected function register_controls() {

        // content -  start

        $this->start_controls_section(
            'content',
            [
                'label' => esc_html__('Content', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT
            ]
        );

        $this->gallery_data_controls();

        $this->end_controls_section();

        // content -  end

        // style -  start

        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__('Style', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
			'layout',
			[
				'label' => esc_html__( 'Layout', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'col-lg-6',
				'options' => [
					'col-lg-6'  => esc_html__( '2 columns', 'rodio' ),
					'col-lg-4' => esc_html__( '3 columns', 'rodio' ),
				]
			]
		);
    
        $this->end_controls_section();

        // style -  end

        // nav styles -  start

        $this->start_controls_section(
            'filter_list_styles',
            [
                'label' => esc_html__('Filter', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'filter_list_typography',
                'label' => esc_html__( 'Text', 'rodio' ),
                'selector' => '{{WRAPPER}} .gallery .filter-list a',
            ]
        );

        $this->start_controls_tabs( 'filer_list_tabs' );

        // normal - start

        $this->start_controls_tab(
            'filter_list_normal',
            [
                'label' => esc_html__( 'Normal', 'rodio' ),
            ]
        );

        $this->add_control(
			'list_color_normal',
			[
				'label' => esc_html__( 'Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery .filter-list a:not(.selected)' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_control(
			'list_bg_color_normal',
			[
				'label' => esc_html__( 'Background Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery .filter-list a:not(.selected)' => 'background-color: {{VALUE}}',
				],
			]
		);

        $this->end_controls_tab();

        // normal - end

        // hover - start

        $this->start_controls_tab(
            'filter_list_hover',
            [
                'label' => esc_html__( 'Hover', 'rodio' ),
            ]
        );

        $this->add_control(
			'list_color_hover',
			[
				'label' => esc_html__( 'Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery .filter-list a:not(.selected):hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .gallery .filter-list a:not(.selected):focus' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_control(
			'list_bg_color_hover',
			[
				'label' => esc_html__( 'Background Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery .filter-list a:not(.selected):hover' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .gallery .filter-list a:not(.selected):focus' => 'background-color: {{VALUE}}',
				],
			]
		);

        $this->end_controls_tab();

        // hover - end

        // active - start

        $this->start_controls_tab(
            'filter_list_active',
            [
                'label' => esc_html__( 'Active', 'rodio' ),
            ]
        );

        $this->add_control(
			'list_color_active',
			[
				'label' => esc_html__( 'Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery .filter-list a.selected' => 'color: {{VALUE}}',
				],
			]
		);

        $this->add_control(
			'list_bg_color_active',
			[
				'label' => esc_html__( 'Background Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery .filter-list a.selected' => 'background-color: {{VALUE}}',
				],
			]
		);

        $this->end_controls_tab();

        // active - end

        $this->end_controls_tabs();

        $this->end_controls_section();

        // nav styles -  end

        // hover -  start

        $this->start_controls_section(
            'hover',
            [
                'label' => esc_html__('Hover', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
			'background_color',
			[
				'label' => esc_html__( 'Background Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hover' => 'background-color: {{VALUE}}',
				],
			]
		);

        $this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hover svg' => 'fill: {{VALUE}}',
				],
			]
		);
    
        $this->end_controls_section();

        // hover -  end

        // dropdown -  start

        rodio_get_tab_dropdown_styles( $this );

        // dropdown -  end
    
    }

    private function category_data_controls() {
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
			'category_text',
			[
				'label' => esc_html__( 'Name', 'rodio' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);

        $this->add_control(
            'category_repeater',
            [
              'label' => __( 'Categories', 'rodio' ),
              'type' => \Elementor\Controls_Manager::REPEATER,
              'fields' => $repeater->get_controls(),
              'title_field' => __( 'Category','rodio' ),
              'title_field' => esc_html( '{{{ category_text }}}' ),
            ]
        );
    }

    private function get_gallery_categories() {
        $settings = $this->get_settings_for_display();
        $repeater = $settings['gallery_repeater'];        

        $result = [];

        foreach ( $repeater as $category ) {
            $name = $category['category'];
            $trimmed = trim( $name );
            $exploded = explode( ',', $trimmed );

            foreach ( $exploded as $value ) {
                array_push( $result, str_replace( ' ', '-', trim( $value )  ) );
            }
        }

        return array_unique( $result );
    }

    private function get_gallery_category( $item ) {

        $result = [];

        $name = $item['category'];
        $trimmed = trim( $name );
        $exploded = explode( ',', $trimmed );

        foreach ( $exploded as $value ) {
            array_push( $result, str_replace( ' ', '-', trim( $value )  ) );
        }

        return $result;

    }

    private function gallery_data_controls() {
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => __( 'Choose Image', 'rodio' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
			'category',
			[
				'label' => esc_html__( 'Category', 'rodio' ),
				'type' => \Elementor\Controls_Manager::TEXT,
                'description' => esc_html__( 'Add comma-separated values', 'rodio' ),
                'label_block' => true
				// 'multiple' => true,
				// 'options' => $this->get_gallery_categories(),
			]
		);

        $this->add_control(
            'gallery_repeater',
            [
              'label' => __( 'Gallery', 'rodio' ),
              'type' => \Elementor\Controls_Manager::REPEATER,
              'fields' => $repeater->get_controls(),
              'title_field' => __( 'Image','rodio' ),
            ]
        );
    }

    private function the_category_list() {
        $categories = $this->get_gallery_categories();
    ?>
    <ul class="filter filter-list">
        <li>
            <a href="#" data-filter="*" class="selected">
                <?php echo esc_html__( 'All', 'rodio' ) ?>
            </a>
        </li>
        <?php foreach ( $categories as $category ): ?>
            <li>
                <a href="#" data-filter=".<?php echo esc_attr( $category ); ?>">
                    <?php echo esc_html( str_replace( '-', ' ', $category ) ); ?>
                </a>
            </li>
        <?php endforeach; ?>
    </ul>
    <select class="filter-select">
        <option value="*" selected data-selected>
            <?php echo esc_html__( 'All', 'rodio' ) ?>
        </option>
        <?php foreach ( $categories as $category ): ?>
            <option value=".<?php echo esc_attr( $category ); ?>">
                <?php echo esc_html( str_replace( '-', ' ', $category ) ); ?>
            </option>
        <?php endforeach; ?>
    </select>
    <?php
    }

    private function the_gallery_image( $item, $class = '' ) {
        if ( !empty( $pre_tag ) ) echo wp_kses( $pre_tag, 'general' );
        $wrapper_class = $this->get_gallery_category( $item );
        array_push( $wrapper_class, 'gallery-item-wrapper', $class );
    ?>
    <div class="<?php echo esc_attr( implode( ' ', $wrapper_class ) ); ?>">
        <a href="<?php echo esc_url( $item['image']['url'] ); ?>" class="gallery-item rodio-glightbox">
            <?php 
                echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( 
                    $item, 
                    'full', 
                    'image' 
                ); 
            ?>
            <div class="hover">
                <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path d="M427.8 266.8l-160 176C264.7 446.3 260.3 448 256 448c-3.844 0-7.703-1.375-10.77-4.156c-6.531-5.938-7.016-16.06-1.078-22.59L379.8 272H16c-8.844 0-15.1-7.155-15.1-15.1S7.156 240 16 240h363.8l-135.7-149.3c-5.938-6.531-5.453-16.66 1.078-22.59c6.547-5.906 16.66-5.469 22.61 1.094l160 176C433.4 251.3 433.4 260.7 427.8 266.8z"/></svg>
            </div>
        </a>
    </div>
    <?php
        if ( !empty( $post_tag ) ) echo wp_kses( $post_tag, 'general' );
    }

    private function the_galley_images() {
        $settings = $this->get_settings_for_display();
        foreach ( $settings['gallery_repeater'] as $item ) {
            $this->the_gallery_image( $item, $settings['layout'] );
        }
    }
  
    protected function render(){
        $settings = $this->get_settings_for_display();

    ?>
        <div class="gallery-wrapper">
            <div class="gallery">
                <!-- category - start -->
                <div class="row">
                    <div class="col-lg-12">
                        <div class="filter-wrapper">
                            <?php $this->the_category_list(); ?>
                        </div>
                    </div>
                </div>
                <!-- category - end -->
                <!-- gallery content - start -->
                <div class="row gallery-row gx-5 gy-lg-5 gy-3">
                    <?php $this->the_galley_images(); ?>
                </div>
                <!-- gallery content - end -->
            </div>
        </div>
    <?php
    }
}
