<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class Hamburger extends \Elementor\Widget_Base

{

    public function get_name()
    {
        return 'rodio_hamburger_menu';
    }

    public function get_title()
    {
        return esc_html__('Hamburger Menu', 'rodio');
    }

    public function get_icon()
    {
        return 'eicon-menu-bar';
    }

    public function get_categories()
    {
        return ['gfxpartner'];
    }

    protected function register_controls()
    {

        // content - start

        $this->start_controls_section(
            'header',
            [
                'label' => esc_html__('Content', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'content_template',
            [
                'label'       => esc_html__( 'Template', 'rodio' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'default'     => '0',
                'options'     => rodio_get_elementor_templates(),
                'description' => esc_html__( 'You can create new templates or customize existing templates by going to the \'Templates\' menu item (Besides the \'Elementor\' menu item) on the dashboard.', 'rodio' ),
            ]
        );

        $this->end_controls_section();

        // content - end

        // style - start

        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__('Style', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
			'direction',
			[
				'label' => esc_html__( 'Direction', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'left'  => esc_html__( 'Left', 'rodio' ),
					'right' => esc_html__( 'Right', 'rodio' ),
				],
			]
		);

        // tabs - start

        $this->start_controls_tabs( 'icon_color' );

        $this->start_controls_tab(
            'icon_normal',
            [
                'label' => esc_html__( 'Normal', 'rodio' ),
            ]
        );

        $this->add_control(
			'icon_color_normal',
			[
				'label' => esc_html__( 'Icon Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .bars .bar' => 'background-color: {{VALUE}}',
				],
			]
		);

        $this->end_controls_tab();

        $this->start_controls_tab(
            'icon_sticky',
            [
                'label' => esc_html__( 'Sticky', 'rodio' ),
            ]
        );

        $this->add_control(
			'icon_color_sticky',
			[
				'label' => esc_html__( 'Icon Color', 'rodio' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'.sticky-nav.scrolled .elementor-element-{{ID}} .bars .bar' => 'background-color: {{VALUE}}',
				],
			]
		);

        $this->end_controls_tab();

        $this->end_controls_tabs();

        // tabs - end

        $this->add_control(
			'width',
			[
				'label' => esc_html__( 'Width', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem', 'vw' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,						
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
					'rem' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .hamburger-content' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->add_control(
			'height',
			[
				'label' => esc_html__( 'Height', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem', 'vh' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,						
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
					'rem' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .hamburger' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->end_controls_section();

        // style - end

    }

    private function get_nav_menu_names() {
        $data = get_terms( 'nav_menu', [ 'hide_empty' => true ] );
        $result = [];
        if ( is_array( $data ) || is_object( $data ) ) {
            foreach( $data as $obj ) {
                $result[ $obj->term_id ] = $obj->name;
            }
        }
        return $result;
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute('main_class', 'class', [ 'hamburger', 'direction-' . $settings['direction'] ]);
    ?>
        <div
        <?php $this->print_render_attribute_string('main_class');  ?>
        >
            <div class="hamburger-wrapper">
                <div class="hamburger-icon">
                    <div class="bars">
                        <div class="bar"></div>
                        <div class="bar"></div>
                        <div class="bar"></div>
                    </div>
                </div>
                <div class="hamburger-content">
                <?php
                    $content = \Elementor\Plugin::instance()->frontend->get_builder_content_for_display( 
                        $settings['content_template']
                    );
                    echo wp_kses( $content, 'elementor-template' );
                ?>
                </div>
                <div class="hamburger-overlay"></div>
            </div>
        </div>
    <?php
    }
}
