<?php

if ( !defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


class HeroSlider1 extends \Elementor\Widget_Base {

  public function get_name(){
    return 'rodio_hero_slider_1';
  }

  public function get_title() {
    return esc_html__( 'Hero Slider 1', 'rodio' );
  }

  public function get_icon() {
    return 'eicon-slider-3d';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // content -  start

    $this->start_controls_section(
      'content',
      [
        'label' => esc_html__('Content', 'rodio'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );

    $this->add_control(
        'hs1_show_boxes',
        [
            'label' => esc_html__( 'Show Boxes', 'rodio' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'label_on' => esc_html__( 'Show', 'rodio' ),
            'label_off' => esc_html__( 'Hide', 'rodio' ),
            'return_value' => 'yes',
            'default' => 'yes',
        ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
        'hs1_content_type',
        [
            'label'       => esc_html__( 'Type', 'rodio' ),
            'type'        => \Elementor\Controls_Manager::SELECT,
            'default'     => 'type_1',
            'options'     => [
                'text' => esc_html__( 'Text', 'rodio' ),
                'template' => esc_html__( 'Template', 'rodio' ),
            ],
        ]
    );

    $repeater->add_control(
        'hs1_wysiwyg',
        [
            'label' => esc_html__('Content', 'rodio'),
            'type' => \Elementor\Controls_Manager::WYSIWYG,
            'rows' => 10,
            'placeholder' => esc_html__('Type your content here', 'rodio'),
            'condition' => [
                'hs1_content_type' => 'text'
            ]
        ]
    );

    $repeater->add_control(
        'hs1_content_template',
        [
            'label'       => esc_html__( 'Template', 'rodio' ),
            'type'        => \Elementor\Controls_Manager::SELECT,
            'default'     => '0',
            'options'     => rodio_get_elementor_templates(),
            'description' => esc_html__( 'You can create new templates or customize existing templates by going to the \'Templates\' menu item (Besides the \'Elementor\' menu item) on the dashboard.', 'rodio' ),
            'condition' => [
                'hs1_content_type' => 'template'
            ]
        ]
    );

    // $repeater->add_group_control(
    //     \Elementor\Group_Control_Background::get_type(),
    //     [
    //         'name' => 'hs1_image',
    //         'label' => esc_html__( 'Background', 'rodio' ),
    //         'types' => [ 'classic', 'gradient', 'video' ],
    //         // 'selector' => '{{WRAPPER}} .content{{CURRENT_ITEM}}',
    //     ]
    // );

    $repeater->add_control(
        'hs1_bg_img',
        [
            'label' => esc_html__( 'Choose Image', 'rodio' ),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ]
    );


    $repeater->add_control(
        'image_box_icon',
        [
            'label' => __('Box icon', 'rodio'),
            'type' => \Elementor\Controls_Manager::ICONS
        ]
    );

    $repeater->add_control(
        'image_box_title',
        [
            'label' => esc_html__( 'Box title', 'rodio' ),
            'type' => \Elementor\Controls_Manager::TEXT,            
            'placeholder' => esc_html__( 'Type title here', 'rodio' ),
        ]
    );

    $repeater->add_control(
        'image_box_content',
        [
            'label' => esc_html__( 'Box content', 'rodio' ),
            'type' => \Elementor\Controls_Manager::TEXTAREA,            
            'placeholder' => esc_html__( 'Type content here', 'rodio' ),
        ]
    );

    $this->add_control(
        'hs1_repeater',
        [
            'label' => __('Slides', 'rodio'),
            'type' => \Elementor\Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'title_field' => __('Slide', 'rodio'),
        ]
    );

    $this->end_controls_section();

    // content -  end

    // slider - start

    $this->start_controls_section(
        'hs1_slider_options',
        [
            'label' => esc_html__('Slider', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT
        ]
    );

    rodio_slider_controls( $this );
    
    $this->end_controls_section();

    // slider - end

    // main style - start

    $this->start_controls_section(
        'hs1_slider_styles',
        [
            'label' => esc_html__('Main', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_responsive_control(
        'hs1_padding',
        [
            'label' => esc_html__( 'Padding', 'rodio' ),
            'type' => \Elementor\Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'rem' ],
            'selectors' => [
                '{{WRAPPER}} .hs1-content .content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]
    );
    
    $this->end_controls_section();


    // main style - end

    // slider nav style - start

    rodio_slide_nav_styles( $this );

    // slider nav style - end

    // box style - start

    $this->start_controls_section(
        'hs1_slider_box_styles',
        [
            'label' => esc_html__('Boxes', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_control(
        'icon_size',
        [
            'label' => esc_html__( 'Icon size', 'rodio' ),
            'type' => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px', 'rem' ],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 1000,
                    'step' => 5,
                ],
                'rem' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .hs1-box .image-box-content .icon-svg' => 'font-size: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
            ],
        ]
    );

    $this->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
            'name' => 'box_heading',
            'label' => esc_html__('Heading typography', 'rodio'),
            'selector' => '{{WRAPPER}} .hs1-box .image-box h4',
        ]
    );

    $this->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
            'name' => 'box_content',
            'label' => esc_html__('Content typography', 'rodio'),
            'selector' => '{{WRAPPER}} .image-box-content .content p',
        ]
    );

    $this->start_controls_tabs( 'box_tabs' );

    // normal - start

    $this->start_controls_tab(
        'box_normal',
        [
            'label' => esc_html__( 'Normal', 'rodio' ),
        ]
    );

    $this->add_control(
        'box_bg_color_normal',
        [
          'label' => esc_html__('Background color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .hs1-box .image-box-content' => 'background-color : {{VALUE}}'
          ]
          
        ]
    );

    $this->add_control(
        'box_icon_color_normal',
        [
          'label' => esc_html__('Icon color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .image-box-content .icon' => 'color : {{VALUE}} !important; fill : {{VALUE}} !important;'
          ]
          
        ]
    );

    $this->add_control(
        'box_heading_color_normal',
        [
          'label' => esc_html__('Heading color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .hs1-box .image-box h4' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $this->add_control(
        'box_content_color_normal',
        [
          'label' => esc_html__('Content color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .hs1-box .image-box-content .content p' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $this->end_controls_tab();

    // normal - end

    // active - start

    $this->start_controls_tab(
        'box_active',
        [
            'label' => esc_html__( 'Active', 'rodio' ),
        ]
    );

    $this->add_control(
        'box_bg_color_active',
        [
          'label' => esc_html__('Background color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .hs1-box .dropped .image-box-content' => 'background-color : {{VALUE}}'
          ]
          
        ]
    );

    $this->add_control(
        'box_icon_color_active',
        [
          'label' => esc_html__('Icon color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .hs1-box .dropped .image-box-content .icon' => 'color : {{VALUE}} !important; fill : {{VALUE}} !important;'
          ]
          
        ]
    );

    $this->add_control(
        'box_heading_color_active',
        [
          'label' => esc_html__('Heading color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .hs1-box .dropped .image-box h4' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $this->add_control(
        'box_content_color_active',
        [
          'label' => esc_html__('Content color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .hs1-box dropped .image-box-content .content p' => 'color : {{VALUE}}'
          ]
          
        ]
    );

    $this->end_controls_tab();

    // active - end

    $this->end_controls_tabs();

    $this->end_controls_section();

    // box style - end

    // reveal styles - start

    rodio_get_image_box_reveal_styles( $this );

    // reveal styles - end
  
  }

  protected function content_slider() {
    $settings = $this->get_settings_for_display();
    $id = $this->get_id() . rand( 0, 999 );


    $this->add_render_attribute( 'hs1_content_slider', 'class', [
        'slider',
        'slider-'.$id,
        'hs1-content'
    ]);

    // options for the image slider
    $options = rodio_slider_options( $settings, $id, [
        'initialSlide' => 0,
    ] );

    $prev_icon = $settings['rs_prev_icon'];
    $next_icon = $settings['rs_next_icon'];

    $content_column = 'col-lg-12';
    if ( $settings['rs_navigation'] == 'yes' ) {
        $content_column = 'col-lg-10';
    }

    ?>
    <div <?php $this->print_render_attribute_string( 'hs1_content_slider' );  ?>>
        <div class="hs1-content-wrapper">
            <div class="swiper-container">
                <div class="swiper-wrapper">

                    <!-- slides - start -->
                    <?php foreach ( $settings['hs1_repeater'] as $item ): ?>
                    <div class="swiper-slide">
                        <div class="content elementor-repeater-item-<?php echo esc_attr( $item['_id'] ); ?>">
                            <div class="hs1-bg">
                                <?php 
                                    echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( 
                                        $item, 
                                        'full', 
                                        'hs1_bg_img' 
                                    ); 
                                ?>
                            </div>
                            <div class="container">
                                <div class="row">
                                    <div class="<?php echo esc_attr( $content_column ); ?>">

                                        <div class="content-slide">
                                            <?php if ( $item['hs1_content_type'] == 'text' ): ?>
                                                <div class="content-slide-inner text">
                                                    <?php echo wp_kses( $item['hs1_wysiwyg'], 'post' ); ?>
                                                </div>
                                            <?php elseif ( $item['hs1_content_type'] == 'template' ): ?>
                                                <div class="content-slide-inner template">
                                                    <?php
                                                        $content = 
                                                        \Elementor\Plugin::instance()->frontend->get_builder_content_for_display( $item['hs1_content_template'] );
                                                        echo wp_kses( $content, 'elementor-template' );
                                                    ?>
                                                </div>
                                            <?php endif; ?>
                                        </div>

                                    </div>
                                </div>
                            </div>
                        </div>

                    </div>
                    <?php endforeach; ?>
                    <!-- slides - end -->
                    
                </div>
            </div>
            <?php if ( $settings['rs_navigation'] == 'yes' ): ?>
            <div class="slider-nav-wrapper">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-2 offset-lg-10 d-lg-flex justify-content-lg-end">
                        <?php 
                            rodio_get_slider_navigation(
                                $id,
                                $prev_icon,
                                $next_icon
                            );
                        ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php endif; ?>
        </div>
    </div>
    <?php
        rodio_slider( $id, $options );
  }

  protected function box_slider() {
    $settings = $this->get_settings_for_display();
    $id = $this->get_id() . rand( 0, 999 );

    $this->add_render_attribute('hs1_slider', 'class', [
        'slider',
        'slider-'.$id,
        'hs1-box'
    ]);

    $options = [
        'rs_slides_per_view' => 1,
        'rs_navigation' => false,
        'rs_autoplay' => false,
        'rs_loop' => false,
        'rs_speed' => 2000,
        'rs_navigation' => $settings['rs_navigation'],
        'rs_prev_icon' => $settings['rs_prev_icon'],
        'rs_next_icon' => $settings['rs_next_icon']
    ];

    // options for the box slider
    $options = rodio_slider_options( $options, $id, 
        [
            'spaceBetween' => 30,
            'slideToClickedSlide' => true,
            'initialSlide' => 0,
            // 'slidesPerGroup' => 3,
            'centeredSlides' => false,
            'breakpoints' => [
                '0' => [
                    'slidesPerView' => 1,
                ],
                '500' => [
                    'slidesPerView' => 1,
                ],
                '992' => [
                    'slidesPerView' => $options['rs_slides_per_view']
                ] 
            ]
        ]
    );

    $prev_icon = $settings['rs_prev_icon'];
    $next_icon = $settings['rs_next_icon'];

    ?>

    <div <?php $this->print_render_attribute_string( 'hs1_slider' );  ?>>
        <div class="hs1-box-wrapper">
            <div class="container">
                <div class="row position-relative">
                    <div class="col-lg-4">
                        <div class="swiper-container">
                            <div class="swiper-wrapper">
                                <!-- slides - start -->
                                <?php foreach ( $settings['hs1_repeater'] as $item ): ?>
                                <div class="swiper-slide">
                                    <?php
                                        get_template_part(
                                            'inc/template-parts/elementor/image',
                                            'box',
                                            [ 'item' => $item ]
                                        );
                                    ?>
                                </div>
                                <?php endforeach; ?>
                                <!-- slides - end -->
                            </div>
                        </div>
                        <?php 
                            rodio_get_slider_navigation(
                                $id,
                                $prev_icon,
                                $next_icon
                            );
                        ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <?php
        rodio_slider($id, $options);
  }
  
  protected function render() {
    $settings = $this->get_settings_for_display();
    $id = $this->get_id() . rand( 0, 999 );

    $this->add_render_attribute('hs1_container', 'class', [
        'hs1'        
    ]);

    $this->add_render_attribute('hs1_container', 'id', [
        'hs1-'.$id
    ]);


    ?>
    <div <?php $this->print_render_attribute_string( 'hs1_container' );  ?>>
        <!-- slider - start -->
        <?php
            $this->content_slider();
            if ( $settings['hs1_show_boxes'] == 'yes' ) {
                $this->box_slider();
            }
        ?>
        <!-- slider - end -->
    </div>
    <?php
  }
}
