<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class IconBoxAlt extends \Elementor\Widget_Base {

  public function get_name(){
    return 'rodio_icon_box_alt';
  }

  public function get_title() {
    return esc_html__('Icon Box Alt', 'rodio');
  }

  public function get_icon() {
    return 'eicon-icon-box';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // content -  start

    $this->start_controls_section(
        'content',
        [
            'label' => esc_html__('Content', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT
        ]
    );


    $this->add_control(
        'content_box_sub_text',
        [
            'label' => esc_html__( 'Sub Text', 'rodio' ),
            'type' => \Elementor\Controls_Manager::TEXT,
        ]
    );

    $this->add_control(
        'content_box_main_text',
        [
            'label' => esc_html__( 'Main Text', 'rodio' ),
            'type' => \Elementor\Controls_Manager::TEXT,
        ]
    );

    $this->add_control(
        'content_box_icon',
        [
            'label' => __('Icon', 'rodio'),
            'type' => \Elementor\Controls_Manager::ICONS,
        ]
    );

    $this->add_control(
        'link',
        [
            'label' => esc_html__('Link', 'rodio'),
            'type' => \Elementor\Controls_Manager::URL,
        
        ]
    );

    $this->end_controls_section();

    // content -  end

    // style -  start

    $this->start_controls_section(
        'style',
        [
          'label' => esc_html__('Style', 'rodio'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_control(
      'icon_color',
      [
        'label' => esc_html__('Icon color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .icon-box-alt .icon' => 'color : {{VALUE}} !important; fill : {{VALUE}} !important;'
        ]
        
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'sub_heading_text',
          'label' => esc_html__('Secondary heading typography', 'rodio'),
          'selector' => '{{WRAPPER}} .icon-box-alt .sub',
      ]
    );

    $this->add_control(
      'sub_heading_color',
      [
        'label' => esc_html__('Secondary heading color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .icon-box-alt .sub' => 'color : {{VALUE}};'
        ]
        
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'primary_heading_text',
          'label' => esc_html__('Primary heading typography', 'rodio'),
          'selector' => '{{WRAPPER}} .icon-box-alt .main',
      ]
    );

    $this->add_control(
      'primary_heading_color',
      [
        'label' => esc_html__('Primary heading color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .icon-box-alt .main' => 'color : {{VALUE}};'
        ]
        
      ]
    );

    $this->end_controls_section();

    // style -  end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();

    if ( $settings['link']['is_external'] )
      $this->add_render_attribute('link_attr', 'target', '_blank');

    if ( $settings['link']['nofollow'] )
      $this->add_render_attribute('link_attr', 'rel', 'nofollow');

    if ( !empty( $settings['link']['url'] ) )
      $this->add_render_attribute('link_attr', 'href', $settings['link']['url']);

  ?>
    <?php if ( ! empty( $settings['link'] ) ): ?>
        <a <?php $this->print_render_attribute_string('link_attr');  ?>>
    <?php endif; ?>
    <div class="icon-box-alt">
        <div class="icon-wrapper">
            <div class="icon-inner">
                <?php rodio_render_icon( $settings['content_box_icon'] ); ?>
            </div>
        </div>
        <div class="content">
            <div class="sub"><?php echo esc_html( $settings['content_box_sub_text'] ); ?></div>
            <div class="main"><?php echo esc_html( $settings['content_box_main_text'] ); ?></div>
        </div>
    </div>
    <?php if ( ! empty( $settings['link'] ) ): ?>
        </a>
    <?php endif; ?>
    <?php
  }
}
