<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class IconBox extends \Elementor\Widget_Base {

  public function get_name(){
    return 'rodio_icon_box';
  }

  public function get_title() {
    return esc_html__('Icon Box', 'rodio');
  }

  public function get_icon() {
    return 'eicon-icon-box';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // content -  start

    $this->start_controls_section(
        'content',
        [
            'label' => esc_html__('Content', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT
        ]
    );


    $this->add_control(
        'content_box_text',
        [
            'label' => esc_html__( 'Text', 'rodio' ),
            'type' => \Elementor\Controls_Manager::TEXT,
        ]
    );

    $this->add_control(
        'content_box_icon',
        [
            'label' => __('Icon', 'rodio'),
            'type' => \Elementor\Controls_Manager::ICONS,
        ]
    );

    $this->end_controls_section();

    // content -  end

    // style -  start

    $this->start_controls_section(
        'style',
        [
          'label' => esc_html__('Style', 'rodio'),
          'tab' => \Elementor\Controls_Manager::TAB_STYLE
        ]
    );

    $this->add_control(
			'padding',
			[
				'label' => esc_html__( 'Padding', 'rodio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .single-icon-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

    $this->add_control(
			'border_radius',
			[
				'label' => esc_html__( 'Border radius', 'rodio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .single-icon-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
          'name' => 'text_typography',
          'label' => esc_html__('Text', 'rodio'),
          'selector' => '{{WRAPPER}} .content',
      ]
    );

    $this->add_control(
      'text_color',
      [
        'label' => esc_html__('Text color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .content' => 'color : {{VALUE}};'
        ]
        
      ]
    );

    $this->add_control(
      'background_color',
      [
        'label' => esc_html__('Background color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .single-icon-box' => 'background-color : {{VALUE}};'
        ]
        
      ]
    );

    $this->add_control(
      'icon_bg_color',
      [
        'label' => esc_html__('Icon background color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .single-icon-box .icon-inner' => 'background-color : {{VALUE}};'
        ]
        
      ]
    );

    $this->add_control(
      'icon_color',
      [
        'label' => esc_html__('Icon color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .single-icon-box .icon-inner' => 'color : {{VALUE}}; fill : {{VALUE}};'
        ]
        
      ]
    );

    $this->add_control(
			'icon_size',
			[
				'label' => esc_html__( 'Icon size', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
          'rem' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .single-icon-box .icon-inner' => 'font-size: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .single-icon-box .icon-inner .icon-svg' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

    $this->end_controls_section();

    // style -  end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
  ?>
    <div class="single-icon-box">
        <div class="content">
            <span><?php echo esc_html( $settings['content_box_text'] ); ?></span>
        </div>
        <div class="icon-wrapper">
            <div class="icon-inner">
                <?php rodio_render_icon( $settings['content_box_icon'] ); ?>
            </div>
        </div>
    </div>
    <?php
  }
}
