<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class ImageBox extends \Elementor\Widget_Base

{

    public function get_name()
    {
        return 'rodio_image_box';
    }

    public function get_title()
    {
        return esc_html__('Image Box', 'rodio');
    }

    public function get_icon()
    {
        return 'eicon-heading';
    }

    public function get_categories()
    {
        return ['gfxpartner'];
    }

    protected function register_controls()
    {

        // content - start

        $this->start_controls_section(
            'image_box_content_section',
            [
                'label' => esc_html__('Content', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
			'column_count',
			[
				'label' => esc_html__( 'Columns', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-6' => esc_html__( '2 Columns', 'rodio' ),
					'col-lg-4' => esc_html__( '3 Columns', 'rodio' ),
                    'col-lg-3' => esc_html__( '4 Columns', 'rodio' ),
				],
			]
		);

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'image_box_image',
            [
                'label' => __( 'Choose Image', 'rodio' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'image_box_icon',
            [
                'label' => __('Icon', 'rodio'),
                'type' => \Elementor\Controls_Manager::ICONS
            ]
        );

        $repeater->add_control(
            'image_box_title',
            [
                'label' => esc_html__( 'Title', 'rodio' ),
                'type' => \Elementor\Controls_Manager::TEXT,            
                'placeholder' => esc_html__( 'Type title here', 'rodio' ),
            ]
        );

        $repeater->add_control(
            'image_box_content',
            [
                'label' => esc_html__( 'Content', 'rodio' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,            
                'placeholder' => esc_html__( 'Type content here', 'rodio' ),
            ]
        );

        $repeater->add_control(
            'image_box_link_text',
            [
                'label' => esc_html__( 'Link Text', 'rodio' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Type link text here', 'rodio' ),
            ]
        );

        $repeater->add_control(
            'image_box_link',
            [
                'label' => esc_html__( 'Link', 'rodio' ),
                'type' => \Elementor\Controls_Manager::URL,
            ]
        );

        $this->add_control(
            'image_box_repeater',
            [
              'label' => __( 'Boxes', 'rodio' ),
              'type' => \Elementor\Controls_Manager::REPEATER,
              'fields' => $repeater->get_controls(),
              'title_field' => __ ( 'Box','rodio' ),
            ]
        );

        $this->end_controls_section();

        // content - end

        // icon styles - start

        rodio_get_image_box_icon_styles( $this );

        // icon styles - end

        // heading styles - start

        rodio_get_image_box_title_styles( $this );

        // heading styles - end

        // content styles - start

        rodio_get_image_box_content_styles( $this );

        // content styles - end

        // link styles - start

        rodio_get_image_box_link_styles( $this );

        // link styles - end

        // reveal styles - start

        rodio_get_image_box_reveal_styles( $this );

        // reveal styles - end

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $columns = 'col-lg-4';
        if ( ! empty( $settings['column_count'] ) )
            $columns = $settings['column_count'];
    ?>
    <div class="image-box-list">
        <div 
        class="row row-masonry gx-5 gy-5"
        data-masonry-options='{ "percentPosition": true, "horizontalOrder": true, "transitionDuration": 0 }'>
            <?php 
                if ( is_array( $settings['image_box_repeater'] ) || is_object( $settings['image_box_repeater'] ) ):
                    foreach ( $settings['image_box_repeater'] as $item ):
            ?>
                <div class="<?php echo esc_attr( $columns ); ?> col-md-6">
                    <?php
                        get_template_part(
                            'inc/template-parts/elementor/image',
                            'box',
                            [ 'item' => $item ]
                        );
                    ?>
                </div>
            <?php
                    endforeach;
                endif;
            ?>
        </div>
    </div>
    <?php
    }
}
