<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class Image extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'rodio_image';
    }

    public function get_title()
    {
        return esc_html__('Image', 'rodio');
    }

    public function get_icon()
    {
        return 'eicon-image';
    }

    public function get_categories()
    {
        return ['gfxpartner'];
    }

    protected function register_controls()
    {

        // content - start

        $this->start_controls_section(
            'r_image_content',
            [
                'label' => esc_html__('Image', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'r_image',
            [
                'label' => __( 'Choose Image', 'rodio' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->end_controls_section();

        // content - end

        // style - start

        $this->start_controls_section(
            'r_image_style',
            [
                'label' => esc_html__('Style', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
			'r_image_extend_switch',
			[
				'label' => esc_html__( 'Extend Image', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'rodio' ),
				'label_off' => esc_html__( 'No', 'rodio' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

        $this->add_control(
			'r_image_extend_type',
			[
				'label' => esc_html__( 'Extend Side', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'left',
				'options' => [
					'left'  => esc_html__( 'Left', 'rodio' ),
					'right' => esc_html__( 'Right', 'rodio' )
				],
                'condition' => [
                    'r_image_extend_switch' => 'yes'
                ]
			]
		);


        $this->add_responsive_control(
			'r_image_height',
			[
				'label' => esc_html__( 'Height', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 200,
					],
                    'rem' => [
						'min' => 0,
						'max' => 1000,
					],
				],
				'selectors' => [
                    '{{WRAPPER}} .r-image-inner' => '--height-elementor: {{SIZE}}{{UNIT}};',
					// '{{WRAPPER}} .r-image-inner' => 'height: {{SIZE}}{{UNIT}};'
				],
			]
		);

        $this->add_control(
			'r_image_ovelap',
			[
				'label' => esc_html__( 'Allow overlap', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'rodio' ),
				'label_off' => esc_html__( 'No', 'rodio' ),
				'return_value' => 'overlap',
				'default' => 'no-overlap',
			]
		);

        $this->add_responsive_control(
			'r_image_border_radius',
			[
				'label' => esc_html__( 'Border radius', 'rodio' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'rem' ],
				'selectors' => [
					'{{WRAPPER}} .r-image-inner' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

        $this->end_controls_section();

        // style - end

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute( 
            'image_extend_type', 
            'data-extend', 
            $settings['r_image_extend_type']
        );

        $this->add_render_attribute( 
            'image_extend_type', 
            'class', 
            [
                'r-image',
                $settings['r_image_ovelap']
            ]
        );

    ?>
        <div        
        <?php $this->print_render_attribute_string('image_extend_type');  ?>
        >
            <div class="r-image-inner">
                <?php 
                    echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( 
                        $settings, 
                        'full', 
                        'r_image' 
                    ); 
                ?>
            </div>
        </div>
    <?php
    }
}
