<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class Logo extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'rodio_logo';
    }

    public function get_title()
    {
        return esc_html__('Logo', 'rodio');
    }

    public function get_icon()
    {
        return 'eicon-logo';
    }

    public function get_categories()
    {
        return ['gfxpartner'];
    }

    protected function register_controls()
    {

        // content - start

        $this->start_controls_section(
            'content',
            [
                'label' => esc_html__('Image', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'important_note',
            [
                'label' => esc_html__( 'Important Note', 'rodio' ),
                'type' => \Elementor\Controls_Manager::RAW_HTML,
                'raw' => '<p style="margin-top: 20px; line-height: normal;">' . 
                __( 'if the section is set to be sticky. the \'normal\' image is hidden on scroll and \'scrolled\' image is shown. Only works for the \'header\' post type.', 'rodio' ) . 
                '</p>'
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => esc_html__('Link', 'rodio'),
                'type' => \Elementor\Controls_Manager::URL,
            
            ]
        );

        $this->start_controls_tabs( 'logo_tabs' );

        $this->start_controls_tab(
            'logo_normal_tab',
            [
                'label' => esc_html__( 'Normal', 'rodio' ),
            ]
        );

        $this->add_control(
            'logo_normal',
            [
                'label' => __( 'Choose Image', 'rodio' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'logo_scrolled_tab',
            [
                'label' => esc_html__( 'Scrolled', 'rodio' ),
            ]
        );

        $this->add_control(
            'logo_scrolled',
            [
                'label' => __( 'Choose Image', 'rodio' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        // content - end

        // style - start

        // $this->start_controls_section(
        //     'r_image_style',
        //     [
        //         'label' => esc_html__('Style', 'rodio'),
        //         'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        //     ]
        // );

        // $this->end_controls_section();

        // style - end

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute( 
            'wrapper', 
            'class', 
            'rodio-logo'
        );

        if ( !empty( $settings['logo_scrolled']['url'] ) ) {
            $this->add_render_attribute( 
                'wrapper', 
                'class', 
                'scrollable'
            );
        }

        if ( $settings['button_link']['is_external'] )
            $this->add_render_attribute('button_attr', 'target', '_blank');

        if ( $settings['button_link']['nofollow'] )
            $this->add_render_attribute('button_attr', 'rel', 'nofollow');

        if ( !empty( $settings['button_link']['url'] ) )
            $this->add_render_attribute('button_attr', 'href', $settings['button_link']['url']);

    ?>
        <div <?php $this->print_render_attribute_string('wrapper');  ?>>
            <a <?php $this->print_render_attribute_string('button_attr');  ?>>
                <div class="normal-logo">
                    <?php 
                        echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( 
                            $settings, 
                            'full', 
                            'logo_normal' 
                        ); 
                    ?>
                </div>
                <div class="scrolled-logo">
                    <?php 
                        echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( 
                            $settings, 
                            'full', 
                            'logo_scrolled' 
                        ); 
                    ?>
                </div>
            </a>
        </div>
    <?php
    }
}
