<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Masonry extends \Elementor\Widget_Base {

  public function get_name(){
    return 'rodio_masonry';
  }

  public function get_title() {
    return esc_html__('Masonry', 'rodio');
  }

  public function get_icon() {
    return 'eicon-button';
  }

  public function get_categories(){
    return ['gfxpartner'];
  }

  protected function register_controls(){

    // button content -  start

    $this->start_controls_section(
      'content',
      [
        'label' => esc_html__('Content', 'rodio'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT
      ]
    );
 
    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
			'content_select',
			[
				'label' => esc_html__( 'Type', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'solid',
				'options' => [
					'image'  => esc_html__( 'Image', 'rodio' ),
					'box' => esc_html__( 'Box', 'rodio' ),
				],
			]
		);

    $repeater->add_control(
      'content_image',
      [
          'label' => __('Choose Image', 'rodio'),
          'type' => \Elementor\Controls_Manager::MEDIA,
          'default' => [
              'url' => \Elementor\Utils::get_placeholder_image_src(),
          ],
          'condition' => [
            'content_select' => 'image'
          ]
      ]
    );

    $repeater->add_control(
			'content_box_text',
			[
				'label' => esc_html__( 'Text', 'rodio' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'condition' => [
          'content_select' => 'box'
        ]
			]
		);

    $repeater->add_control(
      'content_box_icon',
      [
          'label' => __('Icon', 'rodio'),
          'type' => \Elementor\Controls_Manager::ICONS,
          'condition' => [
            'content_select' => 'box'
          ]
      ]
    );

    $this->add_control(
      'content_repeater',
      [
          'label' => __('Items', 'rodio'),
          'type' => \Elementor\Controls_Manager::REPEATER,
          'fields' => $repeater->get_controls(),
          'title_field' => __('Item', 'rodio'),
      ]
    );

    $this->end_controls_section();

    // button content -  end

    // button style -  start

    // button style -  end
  
  }
  

  protected function render(){
    $settings = $this->get_settings_for_display();
  ?>
    <div class="masonry">
      <div
      class="masonry-content row-masonry gx-5 gy-5"
      data-masonry-options='{ "percentPosition": true, "horizontalOrder": true, "gutter": 10 }'>
        <?php foreach( $settings['content_repeater'] as $item ): ?>
          <div class="masonry-item">
            <?php 
              if ( $item['content_select'] === 'image' ) {
                echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( 
                  $item, 
                  'full', 
                  'content_image' 
                );
              } else if ( $item['content_select'] === 'box' )  {
              ?>
              <div class="box">
                <div class="content">
                  <span><?php echo esc_html( $item['content_box_text'] ); ?></span>
                </div>
                <div class="icon-wrapper">
                  <div class="icon-inner">
                    <?php rodio_render_icon( $item['content_box_icon'] ); ?>
                  </div>
                </div>
              </div>
              <?php
              }
            ?>
          </div>
        <?php endforeach; ?>
      </div>
    </div>  
  <?php
  }
}
