<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class Projects extends \Elementor\Widget_Base{

    public function get_name(){
        return 'rodio_projects';
    }
 
    public function get_title(){
        return __( 'Projects', 'rodio' );
    }

    public function get_icon(){
        return 'eicon-device-laptop';
    }

    public function get_categories(){
        return ['gfxpartner'];
    }

    protected function register_controls() {

    // options - start

    rodio_get_projects_options( $this );

    // options - end

    // slider - start

    $this->start_controls_section(
        'ps_section',
        [
            'label' => __( 'Slider', 'rodio' ),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
        ]
    );

    $this->add_control(
        'ps_switch',
        [
            'label' => esc_html__( 'Display as slider', 'rodio' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'label_on' => esc_html__( 'Show', 'rodio' ),
            'label_off' => esc_html__( 'Hide', 'rodio' ),
            'return_value' => 'yes',
            'default' => 'no',
        ]
    );

    rodio_slider_controls( $this, [ 'ps_switch' => 'yes' ] );

    $this->end_controls_section();

    // slider - end

    // load more - start

    $this->start_controls_section(
        'load_more_section',
        [
            'label' => __( 'Load more', 'rodio' ),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            'condition' => [ 'ps_switch!' => 'yes' ]
        ]
    );

    $this->add_control(
        'lm_switch',
        [
            'label' => esc_html__( 'Display load more button', 'rodio' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'label_on' => esc_html__( 'Show', 'rodio' ),
            'label_off' => esc_html__( 'Hide', 'rodio' ),
            'return_value' => 'yes',
            'default' => 'no',
            'condition' => [ 'ps_switch!' => 'yes' ]
        ]
    );

    $this->add_control(
        'load_more_text',
        [
            'label' => esc_html__( 'Text', 'rodio' ),
            'type' => \Elementor\Controls_Manager::TEXT,
            'default' => esc_html__( 'LOAD MORE', 'rodio' ),
            'condition' => [ 'ps_switch!' => 'yes', 'lm_switch' => 'yes' ]
        ]
    );

    $this->end_controls_section();

    // load more - end
  
    // style - start

    rodio_get_projects_style( $this );

    // style - end

    // slider nav - start

    rodio_slide_nav_styles( $this );

    // slider nav - end

    // slider pagination - start

    rodio_slide_pagination_styles( $this );

    // slider pagination - end

    // load more style - start

    $this->start_controls_section(
        'load_more_style_section',
        [
            'label' => __( 'Load more', 'rodio' ),
            'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            'condition' => [ 'ps_switch!' => 'yes', 'lm_switch' => 'yes' ]
        ]
    );

    $this->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
            'name' => 'button_text',
            'label' => esc_html__('Text', 'rodio'),
            'selector' => '{{WRAPPER}} .load-more-button',
        ]
    );

    $this->add_responsive_control(
      'button_align',
      [
          'label'         => esc_html__( 'Alignment', 'rodio' ),
          'type'          => \Elementor\Controls_Manager::CHOOSE,
          'options'       => [
              'left'      => [
                  'title'=> __( 'Left', 'rodio' ),
                  'icon' => 'fa fa-align-left',
              ],
              'center'    => [
                  'title'=> __( 'Center', 'rodio' ),
                  'icon' => 'fa fa-align-center',
              ],
              'right'     => [
                  'title'=> __( 'Right', 'rodio' ),
                  'icon' => 'fa fa-align-right',
              ],
          ],
          'default'       => 'center',
          'selectors'     => [
              '{{WRAPPER}} .load-more-row > div' => 'text-align: {{VALUE}};',
          ],
      ]
    );

    $this->add_responsive_control(
			'width',
			[
				'label' => esc_html__( 'Width', 'rodio' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'rem' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
          'rem' => [
            'min' => 0,
            'max' => 100
          ]
				],
				'selectors' => [
					'{{WRAPPER}} .load-more-button' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

    $this->start_controls_tabs( 'button_tabs' );
    
    $this->start_controls_tab(
        'button_normal',
        [
            'label' => esc_html__( 'Normal', 'rodio' ),
        ]
    );

    $this->add_control(
        'button_text_color',
        [
          'label' => esc_html__('Text color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .load-more-button' => 'color : {{VALUE}} !important; fill : {{VALUE}} !important;'
          ]
          
        ]
    );

    $this->add_control(
      'button_bg_color',
      [
        'label' => esc_html__('Background color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .load-more-button' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );


    $this->end_controls_tab();

    $this->start_controls_tab(
        'button_hover',
        [
            'label' => esc_html__( 'Hover', 'rodio' ),
        ]
    );

    $this->add_control(
        'button_text_color_hover',
        [
          'label' => esc_html__('Text hover color', 'rodio'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .load-more-button:hover' => 'color : {{VALUE}} !important; fill : {{VALUE}} !important;'
          ]
          
        ]
    );

    $this->add_control(
      'button_bg_color_hover',
      [
        'label' => esc_html__('Background color', 'rodio'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .load-more-button:hover' => 'background-color : {{VALUE}}'
        ]
        
      ]
    );

    $this->end_controls_tab();

    $this->end_controls_tabs();

    $this->end_controls_section();

    // load more style - end

    // heading content - start

    $this->start_controls_section(
        'heading_content',
        [
            'label' => esc_html__('Heading', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            'condition' => [ 'ps_switch' => 'yes' ]
        ]
    );

    rodio_heading_data_controls( $this, [ 'ps_switch' => 'yes' ] );

    $this->end_controls_section();

    // heading content - end

    // heading style - start

    $this->start_controls_section(
        'heading_style',
        [
            'label' => esc_html__('Heading', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            'condition' => [ 'ps_switch' => 'yes' ]
        ]
    );

    rodio_heading_style_controls( $this, [ 'ps_switch' => 'yes' ] );

    $this->end_controls_section();

    // heading style - end

  }
  
    private function the_projects( $pre_tag = '', $post_tag = '' ) {
        $settings = $this->get_settings_for_display();

        $args = array(
            'posts_per_page' => esc_attr($settings['rodio_projects_number']),
            'orderby'     => esc_attr($settings['rodio_projects_sort']),
            'order'       => esc_attr($settings['rodio_projects_order']),      
            'post_type' => esc_attr('project'),
            'post_status'    => 'publish'
        );
        
        $query = new \WP_Query( $args );

        if ( $query->have_posts() ) {
            while ( $query->have_posts() ) {
                $query->the_post();
                if ( !empty( $pre_tag ) ) echo wp_kses( $pre_tag, 'general' );
                get_template_part( 
                    '/inc/template-parts/content', 
                    'project' 
                );
                if ( !empty( $post_tag ) ) echo wp_kses( $post_tag, 'general' );
            }
            wp_reset_postdata();
        }
    }

    private function the_projects_slider() {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();

        // options for the slider
        $options = rodio_slider_options( $settings, $id );

        $options = array_merge(
            $options,
            [
                'spaceBetween' => 30,
                'breakpoints' => [
                    '0' => [
                        'slidesPerView' => 1,
                        'centeredSlides' => true,
                        'initialSlide' => 1,
                    ],
                    '992' => [
                        'slidesPerView' => $options['slidesPerView'],
                        'centeredSlides' => false,
                        'initialSlide' => 0,
                    ]
                ]
            ]
        );

        // main class list
        $class_list = [
            'slider',
            'project-slider',
            'slider-'.$id
        ];
    ?>
        <div class="<?php echo esc_html( implode(' ', $class_list) ); ?>">
            <!-- header - start -->
            <?php
                get_template_part( 
                    '/inc/template-parts/elementor/slider', 
                    'header',
                    array(
                        'settings' => $settings,
                        'id' => $id
                    )
                );
            ?>
            <!-- header - end -->
            <!-- slider - start -->
            <div class="row">
                <div class="col-12">
                    <div class="swiper-container overflow-visible">
                        <div class="swiper-wrapper">
                            <?php $this->the_projects( '<div class="swiper-slide">', '</div>' ); ?>
                        </div>
                    </div>
                    <?php rodio_slider_pagination( $settings, $id ); ?>
                </div>
            </div>
            <!-- slider - end -->
        </div>
    <?php
        rodio_slider($id, $options);
    }

    private function the_projects_list() {
        $settings = $this->get_settings_for_display();

        // total projects
        $max = wp_count_posts('project')->publish;

        $nonce = wp_create_nonce( 'projects-load-more' );

        $this->add_render_attribute( 'project_list', 'class', 'project-list-wrapper' );
        $this->add_render_attribute( 'project_list', 'data-max', $max );
        $this->add_render_attribute( 'project_list', 'data-nonce', $nonce );

    ?>
        <div <?php $this->print_render_attribute_string( 'project_list' );  ?>>
            <div 
            class="row row-masonry gx-5 gy-4 project-list-inner" 
            data-masonry-options='{ "percentPosition": true, "horizontalOrder": true }'>
                <?php $this->the_projects( '<div class="col-lg-6">', '</div>' ) ?>
            </div>
            <?php if ( 
                $settings['lm_switch'] == 'yes' && 
                // show if there is something to load more
                (int) $settings['rodio_projects_number'] < $max  ): ?>
            <div class="row load-more-row">
                <div class="col-lg-12">
                    <a
                    href="<?php echo esc_url( home_url() ); ?>/wp-admin/admin-ajax.php"
                    class="button load-more-button">
                        <?php echo esc_html( $settings['load_more_text'] ); ?>
                    </a>
                </div>
            </div>
            <?php endif; ?>
        </div>
    <?php
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
    ?>
        <div class="project-list">
            <?php
                if ( $settings['ps_switch'] == 'yes' ) {
                    $this->the_projects_slider();
                } else {
                    $this->the_projects_list();
                }
            ?>
        </div>
    <?php
    }
}

