<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class Tabs extends \Elementor\Widget_Base

{

    public function get_name()
    {
        return 'rodio_tabs';
    }

    public function get_title()
    {
        return esc_html__('Tabs', 'rodio');
    }

    public function get_icon()
    {
        return 'eicon-tabs';
    }

    public function get_categories()
    {
        return ['gfxpartner'];
    }

    protected function register_controls()
    {

        // content - start

        $this->start_controls_section(
            'r_tab_content',
            [
                'label' => esc_html__('Content', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->start_controls_tabs( 'tab_repeater_tabs' );

        $repeater->start_controls_tab(
            'tab_repeater_content_tab',
            [
                'label' => esc_html__( 'Content', 'rodio' ),
            ]
        );

        rodio_get_tab_content_tab( $repeater );
        
        $repeater->end_controls_tab();

        $repeater->start_controls_tab(
            'tab_repeater_style_tab',
            [
                'label' => esc_html__( 'Style', 'rodio' ),
            ]
        );

        rodio_get_tab_style_tab( $repeater );

        
        $repeater->end_controls_tab();

        $repeater->end_controls_tabs();

        $this->add_control(
            'r_tab_repeater',
            [
                'label' => __('Tabs', 'rodio'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => __('Tab', 'rodio'),
            ]
        );

        $this->end_controls_section();

        // content - end

        // style - start

        rodio_get_tab_main_styles( $this );

        // style - end

        // button style - start

        rodio_get_tab_btn_styles( $this );

        // button style - end

        // icon style - start

        rodio_get_tab_icon_styles( $this );

        // icon style - end

        // text style - start

        rodio_get_tab_btn_txt_styles( $this );

        // text style - end

        // dropdown style - start

        rodio_get_tab_dropdown_styles( $this );

        // dropdown style - end

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();

        $this->add_render_attribute('tab_class', 'class', [ 
            'rodio-tabs', 
            'tab-' . $settings['tab_button_orientation']
        ]);

        $this->add_render_attribute('link_wrapper_class', 'class', [ 
            $settings['tab_main_orientation'] == 'landscape' ? 'col-lg-6' : 'col-lg-12', 
        ]);

        $this->add_render_attribute('link_list_class', 'class', [ 
            'nav',
            'nav-tabs',
            $settings['tab_show_dropdown_on_mobile'] == 'yes' ? 'mobile-hidden' : '',
            $settings['tab_main_orientation'] == 'landscape' ? '' : '', 
        ]);

        $this->add_render_attribute('link_list_class', 'id', [ 
            'tab-container-' . $id
        ]);

        $this->add_render_attribute('link_list_class', 'role', [ 
            'tablist'
        ]);

    ?>
    <div <?php $this->print_render_attribute_string( 'tab_class' ); ?>>
        <div class="rodio-tabs-inner">
            <div class="row gx-5">
                <!-- tab links - start -->
                <div
                <?php $this->print_render_attribute_string( 'link_wrapper_class' ); ?>
                >
                    <ul 
                        <?php $this->print_render_attribute_string( 'link_list_class' ); ?>
                    >
                        <?php
                            if ( is_array( $settings['r_tab_repeater'] ) || is_object( $settings['r_tab_repeater'] ) ) {
                                foreach ( $settings['r_tab_repeater'] as $item ) {
                                    rodio_tab_link( 
                                        $item, 
                                        $item['_id'], 
                                        $settings['tab_main_orientation'] == 'landscape' ? '' : ''
                                    );
                                } 
                            }
                        ?>
                    </ul>
                    <?php if ( $settings['tab_show_dropdown_on_mobile'] == 'yes' ): ?>
                    <select data-source-selector="li button" data-source-target="#<?php echo esc_attr( 'tab-container-' . $id ) ?>">
                        <?php
                            if ( is_array( $settings['r_tab_repeater'] ) || is_object( $settings['r_tab_repeater'] ) ) {
                                foreach ( $settings['r_tab_repeater'] as $item ) {
                                    
                                ?>
                                <option 
                                value="rodio-tab-<?php echo esc_attr( $item['_id'] ); ?>"
                                <?php echo esc_attr( $item['r_tab_active'] == 'yes' ? 'selected data-selected' : '' ); ?>
                                >
                                    &nbsp;
                                </option>
                                <?php
                                } 
                            }
                        ?>
                    </select>
                    <?php endif; ?>
                </div>
                <!-- tab links - end -->
                <!-- tab panes - start -->
                <div class="<?php echo esc_attr( $settings['tab_main_orientation'] == 'landscape' ? 'col-lg-6' : 'col-lg-12'  ); ?>">
                    <div class="tab-content">
                        <?php 
                        if ( is_array( $settings['r_tab_repeater'] ) || is_object( $settings['r_tab_repeater'] ) ) {
                            foreach ( $settings['r_tab_repeater'] as $item ) {
                                rodio_tab_pane( $item, $item['_id'] );
                            } 
                        }
                        ?>
                    </div>
                </div>
                <!-- tab panes - end -->
            </div>
        </div>
    </div>
    <?php
    }
}
