<?php

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

class Team extends \Elementor\Widget_Base

{

    public function get_name()
    {
        return 'rodio_team';
    }

    public function get_title()
    {
        return esc_html__('Team', 'rodio');
    }

    public function get_icon()
    {
        return 'eicon-heading';
    }

    public function get_categories()
    {
        return ['gfxpartner'];
    }

    protected function register_controls()
    {

        // heading content - start

        $this->start_controls_section(
            'heading_content',
            [
                'label' => esc_html__('Heading', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
                'condition' => [ 'team_slider_switch' => 'yes' ]
            ]
        );

        rodio_heading_data_controls( $this, [ 'team_slider_switch' => 'yes' ] );

        $this->end_controls_section();


        // team content - start

        $this->start_controls_section(
            'team_content',
            [
                'label' => esc_html__('Content', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'team_image',
            [
                'label' => __( 'Choose Image', 'rodio' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'team_name',
            [
                'label' => esc_html__( 'Name', 'rodio' ),
                'type' => \Elementor\Controls_Manager::TEXT,            
                'placeholder' => esc_html__( 'Type name here', 'rodio' ),
            ]
        );

        $repeater->add_control(
            'team_designation',
            [
                'label' => esc_html__( 'Designation', 'rodio' ),
                'type' => \Elementor\Controls_Manager::TEXT,            
                'placeholder' => esc_html__( 'Type designation here', 'rodio' ),
            ]
        );

        // $social_repeater = new \Elementor\Repeater();

        // $social_repeater->add_control(
        //     'team_social_icon',
        //     [
        //         'label' => __('Icon', 'rodio'),
        //         'type' => \Elementor\Controls_Manager::ICONS
        //     ]
        // );

        // $social_repeater->add_control(
        //     'team_social_link',
        //     [
        //         'label' => esc_html__('Link', 'rodio'),
        //         'type' => \Elementor\Controls_Manager::URL
        //     ]
        // );

        // $repeater->add_control(
        //     'team_social_repeater',
        //     [
        //       'label' => __( 'Social Links', 'rodio' ),
        //       'type' => \Elementor\Controls_Manager::REPEATER,
        //       'fields' => $social_repeater->get_controls(),
        //       'title_field' => __( 'Social Link', 'rodio' ),
        //     ]
        // );

        $this->add_social_controls( $repeater, 4 );

        $this->add_control(
            'team_repeater',
            [
              'label' => __( 'Team members', 'rodio' ),
              'type' => \Elementor\Controls_Manager::REPEATER,
              'fields' => $repeater->get_controls(),
              'title_field' => esc_html( '{{{ team_name }}}' ),
            ]
        );


        $this->end_controls_section();

        // team content - end

        // slider - start

        $this->start_controls_section(
            'team_slider_section',
            [
                'label' => __( 'Slider', 'rodio' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'team_slider_switch',
            [
                'label' => esc_html__( 'Display as slider', 'rodio' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'rodio' ),
                'label_off' => esc_html__( 'Hide', 'rodio' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        rodio_slider_controls( $this, [ 'team_slider_switch' => 'yes' ] );

        $this->end_controls_section();

        // slider - end

        // team style - start

        $this->start_controls_section(
            'team_style',
            [
                'label' => esc_html__('Style', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'label' => esc_html__('Name typography', 'rodio'),
                'selector' => '{{WRAPPER}} .team-member-content h4',
            ]
        ); 
        
        $this->add_control(
            'name_color',
            [
              'label' => esc_html__('Name color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .team-member-content h4' => 'color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'desgination_typography',
                'label' => esc_html__('Designation typography', 'rodio'),
                'selector' => '{{WRAPPER}} .team-member-content h5',
            ]
        ); 
        
        $this->add_control(
            'desgination_color',
            [
              'label' => esc_html__('Designation color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .team-member-content h5' => 'color : {{VALUE}};'
              ]
              
            ]
        );

        // start tabs

        $this->start_controls_tabs( 'team_tabs' );

        $this->start_controls_tab(
            'team_normal',
            [
                'label' => esc_html__( 'Normal', 'rodio' ),
            ]
        );

        $this->add_control(
            'drop_icon_color_normal',
            [
              'label' => esc_html__('Drop icon color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .reveal' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'social_icon_color_normal',
            [
              'label' => esc_html__('Social icon color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .team-member-content li a' => 'color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'social_icon_bg_color_normal',
            [
              'label' => esc_html__('Social icon background color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .team-member-content li a' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'team_active',
            [
                'label' => esc_html__( 'Active', 'rodio' ),
            ]
        );

        $this->add_control(
            'drop_icon_color_active',
            [
              'label' => esc_html__('Drop icon color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .reveal.plus' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'social_icon_color_active',
            [
              'label' => esc_html__('Social icon color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .team-member-content li:hover a' => 'color : {{VALUE}};'
              ]
              
            ]
        );

        $this->add_control(
            'social_icon_bg_color_active',
            [
              'label' => esc_html__('Social icon background color', 'rodio'),
              'type' => \Elementor\Controls_Manager::COLOR,
              'selectors' => [
                '{{WRAPPER}} .team-member-content li:hover a' => 'background-color : {{VALUE}};'
              ]
              
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        // end tabs

        $this->end_controls_section();

        // team style - end

        // heading style - start

        $this->start_controls_section(
            'team_style_heading',
            [
                'label' => esc_html__('Heading', 'rodio'),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        rodio_heading_style_controls($this);

        $this->end_controls_section();

        // heading style - end

        // slider nav - start

        rodio_slide_nav_styles( $this );

        // slider nav - end

        // slider nav - start

        rodio_slide_pagination_styles( $this );

        // slider nav - end

    }

    private function add_social_controls( $instance, $count ) {
        for ( $i = 1; $i != $count + 1; $i++ ) {
            $instance->add_control(
                'team_social_icon_' . $i,
                [
                    'label' => __('Icon ' . $i, 'rodio'),
                    'type' => \Elementor\Controls_Manager::ICONS
                ]
            );

            $instance->add_control(
                'team_social_link_' . $i,
                [
                    'label' => esc_html__('Link ' . $i, 'rodio'),
                    'type' => \Elementor\Controls_Manager::URL
                ]
            );
        }
    }

    private function the_team_members( $pre_tag = '', $post_tag = '' ) {
        $settings = $this->get_settings_for_display();
        if ( $settings['team_repeater'] == null ) return;
        if ( is_array( $settings['team_repeater'] ) || is_object( $settings['team_repeater'] ) ) {
            foreach( $settings['team_repeater'] as $member ) {
                if ( !empty( $pre_tag ) ) echo wp_kses( $pre_tag, 'general' );
                get_template_part( '/inc/template-parts/elementor/team', 'member', [ 'member' => $member, 'count' => 4 ] );
                if ( !empty( $post_tag ) ) echo wp_kses( $post_tag, 'general' );
            }
        }
    }

    private function rodio_team_slider()
    {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();

        // options for the slider
        $options = rodio_slider_options( $settings, $id, [
            'spaceBetween' => 30,
            'breakpoints' => [
                '0' => [
                    'slidesPerView' => 1,
                    'centeredSlides' => true
                ],
                '500' => [
                    'slidesPerView' => 1,
                    'centeredSlides' => true
                ],
                '992' => [
                    'slidesPerView' => $settings['rs_slides_per_view'],
                    'centeredSlides' => false
                ]
            ]
        ] );

        // main class list
        $class_list = [
            'slider',
            'team-slider',
            'slider-'.$id
        ];
    ?>
    <div class="<?php echo esc_html( implode(' ', $class_list) ); ?>">
        <!-- header - start -->
        <?php
            get_template_part( 
                '/inc/template-parts/elementor/slider', 
                'header', 
                array(
                    'settings' => $settings,
                    'id' => $id
                )
            );
        ?>
        <!-- header - end -->
        <!-- slider - start -->
        <div class="row">
            <div class="col-12">
                <div class="slider-wrapper">
                    <div class="swiper-container overflow-visible">
                        <div class="swiper-wrapper">
                            <?php $this->the_team_members( '<div class="swiper-slide">', '</div>' ); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- slider - end -->
    </div>
    <?php
        rodio_slider($id, $options);
    }


    private function the_team_list() {
    ?>
    <div class="team-list-wrapper">
        <div class="row row-masonry gx-5 gy-5 team-list-inner" 
            data-masonry-options='{ "percentPosition": true, "horizontalOrder": true, "transitionDuration": 0 }'>
            <?php $this->the_team_members( '<div class="col-lg-4">', '</div>' ); ?>
        </div>
    </div>
    <?php
    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
    ?>
        <div class="team-list">
            <?php
                if ( $settings['team_slider_switch'] == 'yes' ) {
                    $this->rodio_team_slider();
                } else {
                    $this->the_team_list();
                }
            ?>
        </div>
    <?php
    }
}
