<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly


class TestimonialSlider extends \Elementor\Widget_Base {

    public function get_name() {
        return 'rodio_testimonial_slider';
    }

    public function get_title() {
        return esc_html__('Testimonials', 'rodio');
    }

    public function get_icon() {
        return 'eicon-testimonial';
    }

    public function get_categories() {
        return ['gfxpartner'];
    }

    protected function register_controls() {

    // content - start

    $this->start_controls_section(
        'testimonial_content',
        [
            'label' => esc_html__('Content', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT
        ]
    );

    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
        'testimonial_slide_image',
        [
            'label' => __( 'Choose Image', 'rodio' ),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'default' => [
                'url' => \Elementor\Utils::get_placeholder_image_src(),
            ],
        ]
    );

    $repeater->add_control(
        'testimonial_slide_content',
        [
            'label' => esc_html__( 'Testimonial', 'rodio' ),
            'type' => \Elementor\Controls_Manager::TEXTAREA,
            'rows' => 10,
            'placeholder' => esc_html__( 'Type your testimonial here', 'rodio' ),
        ]
    );

    $repeater->add_control(
        'testimonial_slide_name',
        [
            'label' => esc_html__( 'Name', 'rodio' ),
            'type' => \Elementor\Controls_Manager::TEXT,            
            'placeholder' => esc_html__( 'Type your name here', 'rodio' ),
        ]
    );

    $repeater->add_control(
        'testimonial_slide_designation',
        [
            'label' => esc_html__( 'Designation', 'rodio' ),
            'type' => \Elementor\Controls_Manager::TEXT,            
            'placeholder' => esc_html__( 'Type your designation here', 'rodio' ),
        ]
    );

    
    $this->add_control(
      'testimonial_slides_repeater',
      [
        'label' => __( 'Image slides', 'rodio' ),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'title_field' => __ ( 'Slide','rodio' ),
      ]
    );

    $this->end_controls_section();

    // content - end

    // slider - start

    $this->start_controls_section(
        'testimonial_slider_options',
        [
            'label' => esc_html__('Slider', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT
        ]
    );

    $this->add_control(
        'ts_switch',
        [
            'label' => esc_html__( 'Display as slider', 'rodio' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'label_on' => esc_html__( 'Show', 'rodio' ),
            'label_off' => esc_html__( 'Hide', 'rodio' ),
            'return_value' => 'yes',
            'default' => 'yes',
        ]
    );

    rodio_slider_controls( $this, [ 'ts_switch' => 'yes' ] );
    
    $this->end_controls_section();

    // heading content - start

    $this->start_controls_section(
        'heading_content',
        [
            'label' => esc_html__('Heading', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            'condition' => [ 'ts_switch' => 'yes' ]
        ]
    );

    rodio_heading_data_controls( $this, [ 'ts_switch' => 'yes' ] );

    $this->end_controls_section();

    // heading content - end

    // heading style - start

    $this->start_controls_section(
        'heading_style',
        [
            'label' => esc_html__('Heading', 'rodio'),
            'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            'condition' => [ 'ts_switch' => 'yes' ]
        ]
    );

    rodio_heading_style_controls( $this, [ 'ts_switch' => 'yes' ] );

    $this->end_controls_section();

    // heading style - end

    // testimony style - start

    rodio_get_testiomonial_testimony_styles( $this );

    // testimony style - end

    // name style - start

    rodio_get_testiomonial_name_styles( $this );

    // name style - end
  
    // designation style - start

    rodio_get_testiomonial_designation_styles( $this );
    
    // designation style - end

    // slider nav - start

    rodio_slide_nav_styles( $this );

    // slider nav - end

    // slider nav - start

    rodio_slide_pagination_styles( $this );

    // slider nav - end
    
  }

    private function the_testimonial( $item, $pre_tag = '', $post_tag = '' ) {
        if ( !empty( $pre_tag ) ) echo wp_kses( $pre_tag, 'general' );
    ?>
        <div class="testimonial-slide">
            <div class="image">
                <?php 
                    echo \Elementor\Group_Control_Image_Size::get_attachment_image_html( 
                        $item, 
                        'full', 
                        'testimonial_slide_image' 
                    ); 
                ?>
            </div>
            <div class="content">
                <div class="content-wrapper">
                    <p><?php echo esc_html( $item['testimonial_slide_content'] ) ?></p>
                </div>
                <div class="details">
                    <h5><?php echo esc_html( $item['testimonial_slide_name'] ) ?></h5>
                    <h6><?php echo esc_html( $item['testimonial_slide_designation'] ) ?></h6>
                </div>
            </div>
        </div>
    <?php
        if ( !empty( $post_tag ) ) echo wp_kses( $post_tag, 'general' );
    }

    private function all_the_testimonials( $pre_tag = '', $post_tag = '' ) {
        $settings = $this->get_settings_for_display();

        if ( is_array( $settings['testimonial_slides_repeater'] ) || is_object( $settings['testimonial_slides_repeater'] ) ) {
            foreach ( $settings['testimonial_slides_repeater'] as $item ) {
                $this->the_testimonial( $item, $pre_tag, $post_tag );
            }
        }
    }
  
    private function the_testimonial_slider() {
        $settings = $this->get_settings_for_display();
        $id = $this->get_id();

        // options for the slider
        $options = rodio_slider_options( $settings, $id, [
            'spaceBetween' => 30,
            'breakpoints' => [
                '0' => [
                    'slidesPerView' => 1,
                    'centeredSlides' => true,
                    'spaceBetween' => 15,
                ],
                '500' => [
                    'slidesPerView' => 1,
                    'centeredSlides' => true,
                    'spaceBetween' => 30,
                ],
                '758' => [
                    'slidesPerView' => 1.9,
                    'centeredSlides' => true
                ],
                '992' => [
                    'slidesPerView' => $settings['rs_slides_per_view'],
                    'centeredSlides' => false
                ]
            ]
        ] );

        // main class list
        $class_list = [
            'slider',
            'testimonial-slider',
            'slider-'.$id
        ];

    ?>
        <div class="<?php echo esc_html( implode(' ', $class_list) ); ?>">
            <!-- header - start -->
            <?php
                get_template_part( 
                    '/inc/template-parts/elementor/slider', 
                    'header', 
                    array(
                        'settings' => $settings,
                        'id' => $id
                    )
                );
            ?>
            <!-- header - end -->
            <!-- slider - start -->
            <div class="row">
                <div class="col-12">
                    <div class="slider-wrapper">
                        <div class="swiper-container overflow-visible">
                            <div class="swiper-wrapper">
                                <?php $this->all_the_testimonials( '<div class="swiper-slide">', '</div>' ); ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- slider - end -->
        </div>
        <?php
            rodio_slider($id, $options);
    }

    private function the_testimonial_list() {
    ?>
    <div class="row gx-5 gy-5">
        <?php $this->all_the_testimonials( '<div class="col-lg-6">', '</div>' ); ?>
    </div>
    <?php
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
    ?>
    <div class="testimonial-main-wrapper">
        <?php 
            if ( $settings['ts_switch'] == 'yes' ) {
                $this->the_testimonial_slider();
            } else {
                $this->the_testimonial_list();
            }
        ?>
    </div>
    <?php
    }

}
