<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package rodio
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function rodio_body_classes( $classes ) {
	global $rodio_opt;

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	// if ( array_key_exists( 'custom_scrollbar', $rodio_opt ) && $rodio_opt['custom_scrollbar'] ) {
	// }
	$classes[] = 'custom-scrollbar';

	return $classes;
}
add_filter( 'body_class', 'rodio_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function rodio_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'rodio_pingback_header' );

if ( !function_exists( 'get_redux_field' ) ) {
	function get_redux_field( $field, $default ) {
		if ( !class_exists( 'Redux' ) ) {
			return $default;
		}

		global $rodio_opt;
		
		if ( isset( $rodio_opt[$field] ) ) {
			return $rodio_opt[$field];
		} else {
			return $default;
		}
	}
}

if ( ! function_exists( 'rodio_get_page_query' ) ) {
	function rodio_get_page_query() {
		if ( get_query_var('paged') ) {
			return get_query_var('paged');
		} elseif ( get_query_var('page') ) {
			return get_query_var('page');
		} else {
			return 1;
		}
	}
}

if ( ! function_exists('rodio_truncate_title') ) {
	function rodio_truncate_title( $title, $id ) {
		if ( is_single( $id ) )
			return $title;
		
		$max = 51;
		if( strlen( $title ) > $max ) {
			return substr( $title, 0, $max ). " ...";
		} else {
			return $title;
		}
	}
}
add_filter( 'the_title', 'rodio_truncate_title', 10, 2 );