<?php
/**
 * The template for displaying all single posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package rodio
 */

	get_header();

	get_template_part( 'inc/template-parts/page', 'header' );

	$date_format = 'default';
	$date_format_field = get_post_meta(get_the_ID(), 'theme_specified_date_format', true);

	if ( $date_format_field === '1' )
		$date_format = 'custom';


	$display_rs_field = get_post_meta(get_the_ID(), 'display_related_posts', true);
	$display_rs = true;
	$display_rs = $display_rs_field === '' || $display_rs_field === '1';
		

	if ( !class_exists( 'Redux' ) ) {
		$rodio_opt = [];
		$rodio_opt['meta_post_date_select'] = 'default';
		$rodio_opt['meta_post_rs_switch'] = true;
		$rodio_opt['brs_heading_txt'] = __( 'Similar News.', 'rodio' );
		$rodio_opt['brs_prev_icon'] = 'default-prev';
		$rodio_opt['brs_next_icon'] = 'default-next';
		$rodio_opt['meta_post_rs_nav_switch'] = '1';
	} else {
		global $rodio_opt;
	}

	$prev_icon = $rodio_opt['brs_prev_icon'];
	$next_icon = $rodio_opt['brs_next_icon'];


	if (  $rodio_opt['meta_post_rs_nav_switch'] == '0' ) {
		$prev_icon = null;
		$next_icon = null;
	}

	if ( $rodio_opt['meta_post_rs_nav_switch'] == '1' && empty( $rodio_opt['brs_prev_icon'] ) ) {
		$prev_icon = 'default-prev';
	}

	if ( $rodio_opt['meta_post_rs_nav_switch'] == '1' && empty( $rodio_opt['brs_next_icon'] ) ) {
		$next_icon = 'default-next';
	}

	$categories = get_the_category();

	$args = [
		'posts_per_page' => 4,
		'post_type' => 'post',
		'post__not_in' => [ $post->ID ],
		'ignore_sticky_posts' => 1,
		'cat' => !empty( $categories ) ? $categories[0]->term_id : null
	];

	$rp_query = new WP_Query( $args );

	// pagination
    $pagination = [
		'before'=> '
			<div class="post-nav-links">
				<h6>'.__('Pages', 'rodio').': </h6>
				<div class="post-nav-links-inner">', 
		'after' => '
				</div>
			</div>'
	];

	$date_class = 'date-' . $date_format;
  
	$col_class = 'col-lg-8 offset-lg-2';

	$is_paginated = ( ! empty( get_next_posts_link() ) ) || ( ! empty( get_previous_posts_link() ) );

	$related_off_comments_on = ! ( $display_rs && $rp_query->have_posts() ) && ( comments_open() || get_comments_number() != 0 );

?>

	<?php while ( have_posts() ): the_post(); ?>
	
	<div class="blog-detail <?php echo esc_attr( $related_off_comments_on ? 'related-off-comments-on' : '' ); ?>">
		<div class="blog-detail-wrapper">
			<div class="container">
				<!-- thumbnail - start -->
				<div class="row">
					<div class="<?php echo esc_attr( ! has_post_thumbnail() ? 'col-lg-8 offset-lg-2' : 'col-lg-10 offset-lg-1' ); ?>">
						<div class="single-blog-post">
							<div
							class="blog-detail-thumbnail <?php echo esc_attr( ! has_post_thumbnail() ? 'no-thumbnail' : '' ); ?>">
								<?php rodio_post_thumbnail( 'rodio-post-detail-thumbnail-size' ); ?>
								<div class="details <?php echo esc_attr( $date_class ); ?>">
									<div class="date">
										<a href="<?php echo esc_url( home_url( get_the_date('Y/m/d') ) ); ?>">
											<?php echo wp_kses( rodio_get_the_date( $date_format ), 'post' ); ?>
										</a>
									</div>
									<div>
										<h6><?php echo esc_html( __( 'By ', 'rodio' ) . get_the_author() ); ?></h6>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
				<!-- thumbnail - end -->
				<?php if ( ! empty( get_the_title() ) ): ?>
				<!-- title - start -->
				<div class="row">
					<div class="col-lg-8 offset-lg-2">
						<div class="blog-detail-content">
							<?php
								the_title( '<h1>', '</h1>' ); 
							?>
						</div>
					</div>
				</div>
				<!-- title - end -->
				<?php endif; ?>
				<?php if ( ! empty( get_the_content() ) ): ?>
				<!-- content - start -->
				<div class="row">
					<div class="<?php echo esc_attr( $col_class ); ?>">
						<div <?php post_class('blog-detail-content-wrapper'); ?>>
							<?php the_content(); ?>
						</div>
					</div>
				</div>
				<!-- content - end -->
				<?php endif; ?>

				<?php if ( $is_paginated || has_tag() ): ?>
				<!-- details - start -->
				<div class="row">
					<div class="<?php echo esc_attr( $col_class ); ?>">
						<!-- blog pagination - start -->
						<div class="pagination-container">
							<?php wp_link_pages($pagination); ?>
						</div>
						<!-- blog pagination - end -->

						<?php if ( has_tag() ): ?>
						<!-- post tags - start -->
						<div class="post-tags">
							<?php the_tags( '<h6>' . __( 'Tags', 'rodio' ) . ': </h6><ul><li>', '</li><li>', '</li></ul>'); ?>
						</div>
						<!-- post tags - end -->
						<?php endif; ?>
					</div>
				</div>
				<!-- details - end -->
				<?php endif; ?>
			</div>
		</div>
	</div>

	<?php if ( $display_rs && $rp_query->have_posts() ): 
	
		
		$options = [
			'r_heading_control' => $rodio_opt['brs_heading_txt'],
			'r_heading_preset'	=> 'normal',

			'rs_prev_icon'		=> $prev_icon,
			'rs_next_icon'		=> $next_icon
		];

		$id = 'related_blog';

		$slider_options = [
			'spaceBetween'		=> 30,
			'resizeObserver' 	=> true,
			'autoHeight'		=> true,
			'navigation' 		=> [
				'nextEl' 		=> '.slider-nav-'.$id.' .slider-nav-next',
				'prevEl' 		=> '.slider-nav-'.$id.' .slider-nav-prev',
			],
			'breakpoints'		=> [
				'0' => [
					'slidesPerView'		=> 1,
					'centeredSlides'	=> true,
				],
				'992' => [
					'slidesPerView'		=> 3,
					'centeredSlides'	=> false,
				],
			]
		];

	?>
	<div class="related-blog-wrapper">
		<div class="related-blog desktop">
			<div class="container">
				<!-- header - start -->
				<?php
					get_template_part( 
						'/inc/template-parts/elementor/slider', 
						'header',
						array(
							'settings' => array_merge( $options ),
							'id' => $id
						)
					);
				?>
				<!-- header - end -->
				<div class="row">
					<div class="col-lg-12">
						<div class="related-blog-slider slider-<?php echo esc_attr( $id ); ?>">
							<div class="swiper-container">
								<div class="swiper-wrapper">
									<?php 
										while ( $rp_query->have_posts() ): 
										$rp_query->the_post();
									?>
										<div class="swiper-slide">
											<?php
												get_template_part( 
													'/inc/template-parts/content', 
													'post',
													[
														'date_format' => 'custom'
													]
												);
											?>
										</div>
									<?php endwhile; wp_reset_postdata(); ?>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<div class="related-blog mobile">
			<div class="container">
				<!-- header - start -->
				<?php
					get_template_part( 
						'/inc/template-parts/elementor/slider', 
						'header',
						array(
							'settings' => array_merge( $options, [ 'rs_prev_icon'	=> null, 'rs_next_icon'	=> null ] ),
							'id' => $id
						)
					);
				?>
				<!-- header - end -->
				<!-- content - start -->
				<div class="row gx-5 gy-5">
				<?php 
					while ( $rp_query->have_posts() ): 
					$rp_query->the_post();
				?>
					<div class="col-lg-12">
						<?php
							get_template_part( 
								'/inc/template-parts/content', 
								'post',
								[
									'date_format' => 'custom'
								]
							);
						?>
					</div>
				<?php endwhile; wp_reset_postdata(); ?>
				</div>
				<!-- content - end -->
			</div>
		</div>
	</div>
	<?php rodio_slider( 'related_blog', $slider_options ); endif; ?>

	<?php 
		if ( comments_open() || get_comments_number() != 0 ) {
			comments_template();
		}
	?>

	<?php endwhile; ?>

	


<?php
get_footer();
